@@ -1,12 +1,12 @@
 /* glpsol.c */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,16 +19,17 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include <limits.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include "glpapi.h"
 #include "glpk.h"
+#include "glpgmp.h"
+#include "glplib.h"
 #include "glpmpl.h"
+#define print xprint1
+#define fault old_fault
 
 /*--------------------------------------------------------------------*/
 /* This program is a stand-alone LP/MIP solver. For pure LP problems  */
@@ -37,10 +38,7 @@
 /* on the simplex method is used.                                     */
 /*--------------------------------------------------------------------*/
 
-static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 4.8";
-/* version string */
-
-static int format = 0;
+static int format = 4;
 /* type of input text file:
    0 - fixed MPS
    1 - CPLEX LP
@@ -83,6 +81,16 @@ static int method = 0;
    1 - interior point
    2 - branch-and-bound */
 
+#if 1 /* 12/XI-2006 */
+static int exact = 0;
+/* if this flag is set, use lpx_exact rather than lpx_simplex */
+#endif
+
+#if 0 /* 12/XI-2006 */
+static int primal = 0;
+/* if this flag is set, use lpx_primal rather than lpx_simplex */
+#endif
+
 static int intopt = 0;
 /* if this flag is set, use lpx_intopt rather than lpx_integer */
 
@@ -127,13 +135,18 @@ static char *out_glp = NULL;
 /* name of output text file, to which the problem should be written in
    GNU LP format; NULL means no GNU LP output */
 
+static char *log_file = NULL;
+/* name of output text file, to which a hardcopy of all screen output
+   should be written; NULL means no hardcopying */
+
 static char *newname = NULL;
 /* new name which has to be assigned to the problem */
 
 static int basis = 1;
 /* which initial basis should be used:
    0 - standard initial basis
-   1 - advanced initial basis */
+   1 - advanced initial basis
+   2 - Bixby's initial basis */
 
 static int price = 1;
 /* which pricing technique should be used:
@@ -149,6 +162,12 @@ static int presol = 1;
 /* if this flag is set, the solver uses the LP presolver; otherwise the
    LP presolver is not used */
 
+#if 1 /* 08/XI-2006 */
+static int xcheck = 0;
+/* if this flag is set, the solver checks the final basis using exact
+   (bignum) arithmetic */
+#endif
+
 static int nomip = 0;
 /* if this flag is set, the solver considers all integer variables as
    continuous (this allows solving MIP problem as pure LP) */
@@ -167,6 +186,13 @@ static int btrack = 2;
    2 - select node using the best projection heuristic
    3 - select node with best local bound */
 
+static int binarize = 0;
+/* if this flag is set, the solver replaces general integer variables
+   by binary ones */
+
+static int use_cuts = 0;
+/* if this flag is set, the solver tries to generate cutting planes */
+
 /*----------------------------------------------------------------------
 -- display_help - display help.
 --
@@ -177,11 +203,13 @@ static void display_help(char *my_name)
 {     print("Usage: %s [options...] filename", my_name);
       print("");
       print("General options:");
+#if 0
       print("   --glp             read LP/MIP model in GNU LP format");
-      print("   --mps             read LP/MIP problem in fixed MPS form"
-         "at (default)");
-      print("   --freemps         read LP/MIP problem in free MPS forma"
-         "t");
+#endif
+      print("   --mps             read LP/MIP problem in Fixed MPS form"
+         "at");
+      print("   --freemps         read LP/MIP problem in Free MPS forma"
+         "t (default)");
       print("   --cpxlp           read LP/MIP problem in CPLEX LP forma"
          "t");
       print("   --math            read LP/MIP model written in GNU Math"
@@ -227,17 +255,21 @@ static void display_help(char *my_name)
       print("   --orig            try using original names of rows and "
          "columns");
       print("                     (default for --mps)");
+#if 0
       print("   --wglp filename   write problem to filename in GNU LP f"
          "ormat");
-      print("   --wmps filename   write problem to filename in fixed MP"
+#endif
+      print("   --wmps filename   write problem to filename in Fixed MP"
          "S format");
       print("   --wfreemps filename");
-      print("                     write problem to filename in free MPS"
+      print("                     write problem to filename in Free MPS"
          " format");
       print("   --wcpxlp filename write problem to filename in CPLEX LP"
          " format");
       print("   --wtxt filename   write problem to filename in plain te"
          "xt format");
+      print("   --log filename    write copy of screen output to filena"
+         "me");
       print("   -h, --help        display this help information and exi"
          "t");
       print("   -v, --version     display program version and exit");
@@ -247,6 +279,7 @@ static void display_help(char *my_name)
          "cks");
       print("   --adv             use advanced initial basis (default)")
          ;
+      print("   --bib             use Bixby's initial basis");
       print("   --bas filename    read initial basis from filename in M"
          "PS format");
       print("   --steep           use steepest edge technique (default)"
@@ -259,6 +292,14 @@ static void display_help(char *my_name)
       print("   --presol          use presolver (default; assumes --sca"
          "le and --adv)");
       print("   --nopresol        do not use presolver");
+#if 1 /* 12/XI-2006 */
+      print("   --exact           use simplex method based on exact ari"
+         "thmetic");
+#endif
+#if 1 /* 08/XI-2006 */
+      print("   --xcheck          check final basis using exact arithme"
+         "tic");
+#endif
       print("   --wbas filename   write final basis to filename in MPS "
          "format");
       print("");
@@ -280,6 +321,16 @@ static void display_help(char *my_name)
       print("                     (default)");
       print("   --bestb           backtrack using node with best local "
          "bound");
+      print("   --intopt          use advanced MIP solver");
+      print("   --binarize        replace general integer variables by "
+         "binary ones");
+      print("                     (assumes --intopt)");
+      print("   --cover           generate mixed cover cuts");
+      print("   --clique          generate clique cuts");
+      print("   --gomory          generate Gomory's mixed integer cuts")
+         ;
+      print("   --cuts            generate all cuts above (assumes --in"
+         "topt)");
       print("");
       print("For description of the MPS and CPLEX LP formats see Refere"
          "nce Manual.");
@@ -303,9 +354,15 @@ static void display_help(char *my_name)
 -- by the GNU Coding Standards. */
 
 static void display_version(void)
-{     print("%s", version);
-      print("Copyright (C) 2000, 01, 02, 03, 04 Andrew Makhorin <mao@ma"
-         "i2.rcnet.ru>");
+{     print("GLPSOL---GLPK LP/MIP Solver, Version %s", glp_version());
+      print("");
+      print("Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makh"
+         "orin,");
+      print("Department for Applied Informatics, Moscow Aviation Instit"
+         "ute,");
+      print("Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcn"
+         "et.ru>.");
+      print("");
       print("This program is free software; you may redistribute it und"
          "er the terms of");
       print("the GNU General Public License. This program has absolutel"
@@ -370,8 +427,6 @@ static void parse_cmdline(int argc, char *argv[])
             method = 0;
          else if (p("--interior"))
             method = 1;
-         else if (p("--intopt"))
-            intopt = 1;
          else if (p("-o") || p("--output"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
@@ -484,6 +539,18 @@ static void parse_cmdline(int argc, char *argv[])
             }
             out_txt = argv[k];
          }
+         else if (p("--log"))
+         {  k++;
+            if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
+            {  print("No log file specified");
+               exit(EXIT_FAILURE);
+            }
+            if (log_file != NULL)
+            {  print("Only one log file allowed");
+               exit(EXIT_FAILURE);
+            }
+            log_file = argv[k];
+         }
          else if (p("--wglp"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
@@ -500,10 +567,16 @@ static void parse_cmdline(int argc, char *argv[])
             display_help(argv[0]);
          else if (p("-v") || p("--version"))
             display_version();
+#if 0 /* 12/XI-2006 */
+         else if (p("--primal"))
+            primal = 1;
+#endif
          else if (p("--std"))
-            basis = 0;
+            basis = 0, presol = 0;
          else if (p("--adv"))
-            basis = 1;
+            basis = 1, presol = 0;
+         else if (p("--bib"))
+            basis = 2, presol = 0;
          else if (p("--bas"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
@@ -528,6 +601,14 @@ static void parse_cmdline(int argc, char *argv[])
             presol = 1;
          else if (p("--nopresol"))
             presol = 0;
+#if 1 /* 12/XI-2006 */
+         else if (p("--exact"))
+            exact = 1, presol = 0;
+#endif
+#if 1 /* 08/XI-2006 */
+         else if (p("--xcheck"))
+            xcheck = 1;
+#endif
          else if (p("--wbas"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
@@ -558,6 +639,18 @@ static void parse_cmdline(int argc, char *argv[])
             btrack = 2;
          else if (p("--bestb"))
             btrack = 3;
+         else if (p("--intopt"))
+            intopt = 1;
+         else if (p("--binarize"))
+            intopt = 1, binarize = 1;
+         else if (p("--cover"))
+            intopt = 1, use_cuts |= LPX_C_COVER;
+         else if (p("--clique"))
+            intopt = 1, use_cuts |= LPX_C_CLIQUE;
+         else if (p("--gomory"))
+            intopt = 1, use_cuts |= LPX_C_GOMORY;
+         else if (p("--cuts"))
+            intopt = 1, use_cuts |= LPX_C_ALL;
          else if (argv[k][0] == '-' ||
                  (argv[k][0] == '-' && argv[k][1] == '-'))
          {  print("Invalid option `%s'; try %s --help",
@@ -585,12 +678,18 @@ int main(int argc, char *argv[])
 {     LPX *lp;
       MPL *mpl = NULL;
       int ret;
-      double start;
+      ulong_t start;
       /* parse command line parameters */
       parse_cmdline(argc, argv);
       /* set available memory limit */
+#if 0
       if (memlim >= 0 && memlim < INT_MAX / (1024 * 1024))
          lib_env_ptr()->mem_limit = (1024 * 1024) * memlim;
+#else
+      if (memlim >= 0)
+         lib_link_env()->mem_limit =
+            ulmul(ulset(0, 1024 * 1024), ulset(0, memlim));
+#endif
       /* remove all output files specified in the command line */
       if (display != NULL) remove(display);
       if (out_bas != NULL) remove(out_bas);
@@ -601,6 +700,14 @@ int main(int argc, char *argv[])
       if (out_cpxlp != NULL) remove(out_cpxlp);
       if (out_txt != NULL) remove(out_txt);
       if (out_glp != NULL) remove(out_glp);
+      if (log_file != NULL) remove(log_file);
+      /* open hardcopy file, if necessary */
+      if (log_file != NULL)
+      {  if (lib_open_log(log_file))
+         {  print("Unable to create log file");
+            exit(EXIT_FAILURE);
+         }
+      }
       /* read problem data from the input file */
       if (in_file == NULL)
       {  print("No input file specified; try %s --help", argv[0]);
@@ -623,13 +730,6 @@ int main(int argc, char *argv[])
             }
             break;
          case 2:
-#if 0 /* 01/VIII-2004 */
-            lp = lpx_read_model(in_file, in_data, display);
-            if (lp == NULL)
-            {  print("Model processing error");
-               exit(EXIT_FAILURE);
-            }
-#else
             /* initialize the translator database */
             mpl = mpl_initialize();
             /* read model section and optional data section */
@@ -638,21 +738,21 @@ int main(int argc, char *argv[])
 err:        {  print("Model processing error");
                exit(EXIT_FAILURE);
             }
-            insist(ret == 1 || ret == 2);
+            xassert(ret == 1 || ret == 2);
             /* read data section, if necessary */
             if (in_data != NULL)
-            {  insist(ret == 1);
+            {  xassert(ret == 1);
                ret = mpl_read_data(mpl, in_data);
                if (ret == 4) goto err;
-               insist(ret == 2);
+               xassert(ret == 2);
             }
             /* generate model */
             ret = mpl_generate(mpl, display);
             if (ret == 4) goto err;
             /* extract problem instance */
             lp = lpx_extract_prob(mpl);
-            insist(lp != NULL);
-#endif
+            xassert(lp != NULL);
+#if 0
             if (lpx_get_num_rows(lp) == 0)
             {  print("Problem has no rows");
                exit(EXIT_FAILURE);
@@ -661,6 +761,7 @@ err:        {  print("Model processing error");
             {  print("Problem has no columns");
                exit(EXIT_FAILURE);
             }
+#endif
             break;
          case 3:
             lp = lpx_read_prob(in_file);
@@ -677,7 +778,7 @@ err:        {  print("Model processing error");
             }
             break;
          default:
-            insist(format != format);
+            xassert(format != format);
       }
       /* order rows and columns of the constraint matrix */
       lpx_order_matrix(lp);
@@ -731,9 +832,24 @@ err:        {  print("Model processing error");
       if (check) goto skip;
       /* scale the problem data (if required) */
       if (scale && (!presol || method == 1)) lpx_scale_prob(lp);
-      /* build advanced initial basis (if required) */
-      if (method == 0 && basis && !presol && in_bas == NULL)
-         lpx_adv_basis(lp);
+      /* build initial LP basis */
+      if (method == 0 && !presol && in_bas == NULL)
+      {  switch (basis)
+         {  case 0:
+               lpx_std_basis(lp);
+               break;
+            case 1:
+               if (lpx_get_num_rows(lp) > 0 && lpx_get_num_cols(lp) > 0)
+                  lpx_adv_basis(lp);
+               break;
+            case 2:
+               if (lpx_get_num_rows(lp) > 0 && lpx_get_num_cols(lp) > 0)
+                  lpx_cpx_basis(lp);
+               break;
+            default:
+               xassert(basis != basis);
+         }
+      }
       /* or read initial basis from input text file in MPS format */
       if (in_bas != NULL)
       {  if (method != 0)
@@ -762,12 +878,23 @@ nobs:    ;
       lpx_set_int_parm(lp, LPX_K_BRANCH, branch);
       lpx_set_int_parm(lp, LPX_K_BTRACK, btrack);
       lpx_set_real_parm(lp, LPX_K_TMLIM, (double)tmlim);
+      lpx_set_int_parm(lp, LPX_K_BINARIZE, binarize);
+      lpx_set_int_parm(lp, LPX_K_USECUTS, use_cuts);
       /* solve the problem */
-      start = utime();
+      start = xtime();
       switch (method)
       {  case 0:
             if (nomip || lpx_get_class(lp) == LPX_LP)
-            {  ret = lpx_simplex(lp);
+            {  ret = (!exact ? lpx_simplex(lp) : lpx_exact(lp));
+#if 1 /* 08/XI-2006 */
+               if (xcheck)
+               {  if (!presol || ret == LPX_E_OK)
+                     lpx_exact(lp);
+                  else
+                     print("If you need checking final basis for non-op"
+                        "timal solution, use --nopresol");
+               }
+#endif
                if (presol && ret != LPX_E_OK && (out_bas != NULL ||
                   out_sol != NULL))
                   print("If you need actual output for non-optimal solu"
@@ -775,9 +902,12 @@ nobs:    ;
             }
             else
             {  method = 2;
-               lpx_simplex(lp);
                if (!intopt)
+               {  ret = (!exact ? lpx_simplex(lp) : lpx_exact(lp));
+                  if (xcheck && (!presol || ret == LPX_E_OK))
+                     lpx_exact(lp);
                   lpx_integer(lp);
+               }
                else
                   lpx_intopt(lp);
             }
@@ -792,14 +922,22 @@ nobs:    ;
             }
             break;
          default:
-            insist(method != method);
+            xassert(method != method);
       }
       /* display statistics */
-      print("Time used:   %.1f secs", utime() - start);
+      print("Time used:   %.1f secs", xdifftime(xtime(), start));
+#if 0
       print("Memory used: %.1fM (%d bytes)",
-         (double)lib_env_ptr()->mem_tpeak / (double)(1024 * 1024),
-         lib_env_ptr()->mem_tpeak);
-#if 1 /* 01/VIII-2004 */
+         (double)lib_link_env()->mem_tpeak / (double)(1024 * 1024),
+         lib_link_env()->mem_tpeak);
+#else
+      {  double tpeak;
+         tpeak = (double)lib_link_env()->mem_tpeak.hi;
+         tpeak *= 4294967296.0;
+         tpeak += (double)lib_link_env()->mem_tpeak.lo;
+         print("Memory used: %.1fM", tpeak / (double)(1024 * 1024));
+      }
+#endif
       if (mpl != NULL && mpl_has_solve_stmt(mpl))
       {  int n, j, round;
          /* store the solution to the translator database */
@@ -820,7 +958,7 @@ nobs:    ;
                   mpl_put_col_value(mpl, j, lpx_mip_col_val(lp, j));
                break;
             default:
-               insist(method != method);
+               xassert(method != method);
          }
          lpx_set_int_parm(lp, LPX_K_ROUND, round);
          /* perform postsolving */
@@ -829,9 +967,8 @@ nobs:    ;
          {  print("Model postsolving error");
             exit(EXIT_FAILURE);
          }
-         insist(ret == 3);
+         xassert(ret == 3);
       }
-#endif
       /* write final LP basis (if required) */
       if (out_bas != NULL)
       {  lpx_set_int_parm(lp, LPX_K_MPSORIG, orig);
@@ -854,7 +991,7 @@ nobs:    ;
                ret = lpx_print_mip(lp, out_sol);
                break;
             default:
-               insist(method != method);
+               xassert(method != method);
          }
          if (ret != 0)
          {  print("Unable to write problem solution");
@@ -876,13 +1013,25 @@ nobs:    ;
       }
 skip: /* delete the problem object */
       lpx_delete_prob(lp);
-#if 1 /* 01/VIII-2004 */
       /* if the translator database exists, destroy it */
       if (mpl != NULL) mpl_terminate(mpl);
+#if 1 /* 08/XI-2006 */
+      xassert(gmp_pool_count() == 0);
+      gmp_free_mem();
 #endif
+
+      if (log_file != NULL) lib_close_log();
+
       /* check that no memory blocks are still allocated */
-      insist(lib_env_ptr()->mem_total == 0);
-      insist(lib_env_ptr()->mem_count == 0);
+#if 0
+      xassert(lib_link_env()->mem_total == 0);
+      xassert(lib_link_env()->mem_count == 0);
+#else
+      xassert(ulcmp(lib_link_env()->mem_total, ulset(0, 0)) == 0);
+      xassert(lib_link_env()->mem_count == 0);
+#endif
+      /* free the library environment */
+      lib_free_env();
       /* return to the control program */
       return 0;
 }
