@@ -1,12 +1,12 @@
 /* tspsol.c */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,18 +19,17 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include <float.h>
-#include <limits.h>
-#include <math.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include "glpapi.h"
 #include "glpk.h"
+#include "glplib.h"
+#include "glpios.h"
 #include "glptsp.h"
+#define print xprint1
+#define fault old_fault
 
 /*----------------------------------------------------------------------
 -- This program is a stand-alone solver intended for solving Symmetric
@@ -180,7 +179,7 @@ static double greedy_tour(TSP *tsp, int tour[])
 {     int i, j, k, d, dmin, *flag;
       double sum;
       /* flag[i] means that i-th node has been visited */
-      flag = ucalloc(1+nodes, sizeof(int));
+      flag = xcalloc(1+nodes, sizeof(int));
       for (i = 1; i <= nodes; i++) flag[i] = 0;
       tour[1] = 1, flag[1] = 1;
       for (i = 2; i <= nodes; i++)
@@ -191,10 +190,10 @@ static double greedy_tour(TSP *tsp, int tour[])
                if (dmin > d) k = j, dmin = d;
             }
          }
-         insist(k != 0);
+         xassert(k != 0);
          tour[i] = k, flag[k] = 1;
       }
-      ufree(flag);
+      xfree(flag);
       /* compute length of the tour found */
       sum = 0.0;
       for (i = 1; i <= nodes; i++)
@@ -225,7 +224,7 @@ static void initialize(IOS *ios)
          ios_set_row_bnds(ios, i, IOS_FX, 2.0, 2.0);
       }
       /* find an initial tour using the greedy heuristic */
-      tour = ucalloc(1+nodes, sizeof(int));
+      tour = xcalloc(1+nodes, sizeof(int));
       sum = greedy_tour(tsp, tour);
       print("Initial tour length: %g", sum);
       /* set global upper bound found by the primal heuristic */
@@ -251,7 +250,7 @@ static void initialize(IOS *ios)
          ind[2] = j, val[2] = 1.0;
          ios_set_mat_col(ios, k, 2, ind, val);
       }
-      ufree(tour);
+      xfree(tour);
       return;
 }
 
@@ -270,9 +269,9 @@ static void initialize(IOS *ios)
 static int obtain_col(IOS *ios, int i, int j, int ind[], double val[])
 {     SUBTOUR *subt;
       int k, len, nrows, *cut;
-      insist(1 <= i && i < j && j <= nodes);
+      xassert(1 <= i && i < j && j <= nodes);
       /* allocate and clear working array */
-      cut = ucalloc(1+nodes, sizeof(int));
+      cut = xcalloc(1+nodes, sizeof(int));
       for (k = 1; k <= nodes; k++) cut[k] = 0;
       /* first nodes rows always correspond to degree constraints, in
          which any column has exactly two constraint coefficients */
@@ -284,7 +283,7 @@ static int obtain_col(IOS *ios, int i, int j, int ind[], double val[])
       nrows = ios_get_num_rows(ios);
       for (k = nodes+1; k <= nrows; k++)
       {  /* restore corresponding cut (W, V \ W) */
-         insist(ios_get_row_mark(ios, k) == SUBTOUR_MARK);
+         xassert(ios_get_row_mark(ios, k) == SUBTOUR_MARK);
          for (subt = (SUBTOUR *)ios_get_row_link(ios, k); subt != NULL;
             subt = subt->next) cut[subt->i] = 1;
          /* if edge (i,j) gets under the cut, the corresponding column
@@ -299,7 +298,7 @@ static int obtain_col(IOS *ios, int i, int j, int ind[], double val[])
             subt = subt->next) cut[subt->i] = 0;
       }
       /* free working array */
-      ufree(cut);
+      xfree(cut);
       return len;
 }
 
@@ -322,8 +321,8 @@ static void gen_edge_col(IOS *ios, int infeas)
       nrows = ios_get_num_rows(ios);
       ncols = ios_get_num_cols(ios);
       /* allocate working arrays */
-      ind = ucalloc(1+nrows, sizeof(int));
-      val = ucalloc(1+nrows, sizeof(double));
+      ind = xcalloc(1+nrows, sizeof(int));
+      val = xcalloc(1+nrows, sizeof(double));
       /* nothing is chosen so far */
       best_rc = 0.0, best_i = 0, best_j = 0;
       /* walk through all edges of the graph */
@@ -332,7 +331,7 @@ static void gen_edge_col(IOS *ios, int infeas)
          {  /* if column that corresponds to edge (i,j) is already in
                the current subproblem, skip it */
             for (k = 1; k <= ncols; k++)
-            {  insist(ios_get_col_mark(ios, k) == EDGE_MARK);
+            {  xassert(ios_get_col_mark(ios, k) == EDGE_MARK);
                edge = ios_get_col_link(ios, k);
                if (edge->i == i && edge->j == j) goto skip;
             }
@@ -368,8 +367,8 @@ skip:       ;
          ios_set_mat_col(ios, k, len, ind, val);
       }
       /* free working arrays */
-      ufree(ind);
-      ufree(val);
+      xfree(ind);
+      xfree(val);
       return;
 }
 
@@ -404,14 +403,14 @@ static double max_flow(int nn, int ne, int beg[], int end[],
       int i, k, nz, *rn, *cn;
       double flow, *aa;
       /* some sanity checks */
-      insist(nn > 0);
-      insist(ne >= 0);
-      insist(1 <= s && s <= nn);
-      insist(1 <= t && t <= nn);
-      insist(s != t);
+      xassert(nn > 0);
+      xassert(ne >= 0);
+      xassert(1 <= s && s <= nn);
+      xassert(1 <= t && t <= nn);
+      xassert(s != t);
       for (k = 1; k <= ne; k++)
-      {  insist(1 <= beg[k] && beg[k] < end[k] && end[k] <= nn);
-         insist(cap[k] > 0.0);
+      {  xassert(1 <= beg[k] && beg[k] < end[k] && end[k] <= nn);
+         xassert(cap[k] > 0.0);
       }
       /* create LP problem instance */
       lp = lpx_create_prob();
@@ -436,9 +435,9 @@ static double max_flow(int nn, int ne, int beg[], int end[],
          incidence matrix of the network, so each its column (including
          the last column for the dummy edge) has exactly two non-zero
          entries */
-      rn = ucalloc(1 + 2 * (ne + 1), sizeof(int));
-      cn = ucalloc(1 + 2 * (ne + 1), sizeof(int));
-      aa = ucalloc(1 + 2 * (ne + 1), sizeof(double));
+      rn = xcalloc(1 + 2 * (ne + 1), sizeof(int));
+      cn = xcalloc(1 + 2 * (ne + 1), sizeof(int));
+      aa = xcalloc(1 + 2 * (ne + 1), sizeof(double));
       nz = 0;
       for (k = 1; k <= ne; k++)
       {  /* x[k] > 0 means the elementary flow through the k-th edge
@@ -451,12 +450,12 @@ static double max_flow(int nn, int ne, int beg[], int end[],
       nz++, rn[nz] = t, cn[nz] = ne + 1, aa[nz] = -1.0;
       nz++, rn[nz] = s, cn[nz] = ne + 1, aa[nz] = +1.0;
       /* check number of non-zero entries */
-      insist(nz == 2 * (ne + 1));
+      xassert(nz == 2 * (ne + 1));
       /* load the constraint matrix into the LP problem object */
       lpx_load_matrix(lp, nz, rn, cn, aa);
-      ufree(rn);
-      ufree(cn);
-      ufree(aa);
+      xfree(rn);
+      xfree(cn);
+      xfree(aa);
       /* the objective function is the total flow through the network,
          which should be maximized */
       lpx_set_obj_dir(lp, LPX_MAX);
@@ -465,8 +464,8 @@ static double max_flow(int nn, int ne, int beg[], int end[],
       lpx_set_int_parm(lp, LPX_K_MSGLEV, 2);
       lpx_set_real_parm(lp, LPX_K_OUTDLY, 5.0);
       lpx_adv_basis(lp);
-      insist(lpx_simplex(lp) == LPX_E_OK);
-      insist(lpx_get_status(lp) == LPX_OPT);
+      xassert(lpx_simplex(lp) == LPX_E_OK);
+      xassert(lpx_get_status(lp) == LPX_OPT);
       /* obtain the maximum flow through the network and the elementary
          flows through edges that correspond to the optimal solution */
       flow = lpx_get_obj_val(lp);
@@ -515,10 +514,10 @@ static double min_st_cut(int nn, int ne, int beg[], int end[],
          next1[k] points to the next edge with the same beg[k]
          head2[i] points to the first edge with end[k] = i
          next2[k] points to the next edge with the same end[k] */
-      head1 = ucalloc(1+nn, sizeof(int));
-      head2 = ucalloc(1+nn, sizeof(int));
-      next1 = ucalloc(1+ne, sizeof(int));
-      next2 = ucalloc(1+ne, sizeof(int));
+      head1 = xcalloc(1+nn, sizeof(int));
+      head2 = xcalloc(1+nn, sizeof(int));
+      next1 = xcalloc(1+ne, sizeof(int));
+      next2 = xcalloc(1+ne, sizeof(int));
       for (i = 1; i <= nn; i++) head1[i] = head2[i] = 0;
       for (k = 1; k <= ne; k++)
       {  i = beg[k], next1[k] = head1[i], head1[i] = k;
@@ -528,7 +527,7 @@ static double min_st_cut(int nn, int ne, int beg[], int end[],
          nodes, which can be reached from the source node and have been
          visited, and list[p], ..., list[q] contain nodes, which can be
          reached from the source node but havn't been visited yet */
-      list = ucalloc(1+nn, sizeof(int));
+      list = xcalloc(1+nn, sizeof(int));
       for (i = 1; i <= nn; i++) cut[i] = 0;
       p = q = 1, list[1] = s, cut[s] = 1;
       while (p <= q)
@@ -538,7 +537,7 @@ static double min_st_cut(int nn, int ne, int beg[], int end[],
          /* walk through edges with beg[k] = i */
          for (k = head1[i]; k != 0; k = next1[k])
          {  j = end[k];
-            insist(beg[k] == i);
+            xassert(beg[k] == i);
             /* from v[i] we can reach v[j], if the elementary flow from
                v[i] to v[j] is non-saturated */
             if (cut[j] == 0 && x[k] <= + (cap[k] - 1e-7))
@@ -547,7 +546,7 @@ static double min_st_cut(int nn, int ne, int beg[], int end[],
          /* walk through edges with end[k] = i */
          for (k = head2[i]; k != 0; k = next2[k])
          {  j = beg[k];
-            insist(end[k] == i);
+            xassert(end[k] == i);
             /* from v[i] we can reach v[j], if the elementary flow from
                v[i] to v[j] is non-saturated */
             if (cut[j] == 0 && x[k] >= - (cap[k] - 1e-7))
@@ -555,13 +554,13 @@ static double min_st_cut(int nn, int ne, int beg[], int end[],
          }
       }
       /* the sink cannot belong to V(s) */
-      insist(cut[t] == 0);
+      xassert(cut[t] == 0);
       /* free working arrays */
-      ufree(head1);
-      ufree(head2);
-      ufree(next1);
-      ufree(next2);
-      ufree(list);
+      xfree(head1);
+      xfree(head2);
+      xfree(next1);
+      xfree(next2);
+      xfree(list);
       /* compute value of the corresponding minimal (s,t)-cut */
       temp = 0.0;
       for (k = 1; k <= ne; k++)
@@ -619,20 +618,20 @@ static double stoer_wagner(int nn, int ne, int beg[], int end[],
          DEG, NV, NE, *BEG, *END, *HEAD, *NEXT, *NUMB, *ADJ, *CUT;
       double min_cut, flow, temp, *X, *CAP, *SUM;
       /* some sanity checks */
-      insist(nn > 0);
-      insist(ne >= 0);
+      xassert(nn > 0);
+      xassert(ne >= 0);
       for (k = 1; k <= ne; k++)
-      {  insist(1 <= beg[k] && beg[k] < end[k] && end[k] <= nn);
-         insist(cap[k] > 0.0);
+      {  xassert(1 <= beg[k] && beg[k] < end[k] && end[k] <= nn);
+         xassert(cap[k] > 0.0);
       }
       /* head1[i] points to the first edge with beg[k] = i
          next1[k] points to the next edge with the same beg[k]
          head2[i] points to the first edge with end[k] = i
          next2[k] points to the next edge with the same end[k] */
-      head1 = ucalloc(1+nn, sizeof(int));
-      head2 = ucalloc(1+nn, sizeof(int));
-      next1 = ucalloc(1+ne, sizeof(int));
-      next2 = ucalloc(1+ne, sizeof(int));
+      head1 = xcalloc(1+nn, sizeof(int));
+      head2 = xcalloc(1+nn, sizeof(int));
+      next1 = xcalloc(1+ne, sizeof(int));
+      next2 = xcalloc(1+ne, sizeof(int));
       for (i = 1; i <= nn; i++) head1[i] = head2[i] = 0;
       for (k = 1; k <= ne; k++)
       {  i = beg[k], next1[k] = head1[i], head1[i] = k;
@@ -650,20 +649,20 @@ static double stoer_wagner(int nn, int ne, int beg[], int end[],
       /* initially the auxiliary network is equivalent to the original
          network, i.e. each supernode consists of one node */
       NV = nn;
-      HEAD = ucalloc(1+nn, sizeof(int));
-      NEXT = ucalloc(1+nn, sizeof(int));
-      NUMB = ucalloc(1+nn, sizeof(int));
+      HEAD = xcalloc(1+nn, sizeof(int));
+      NEXT = xcalloc(1+nn, sizeof(int));
+      NUMB = xcalloc(1+nn, sizeof(int));
       for (i = 1; i <= nn; i++) HEAD[i] = i, NEXT[i] = 0, NUMB[i] = i;
       /* number of edges in the auxiliary network is never greater than
          in the original one */
-      BEG = ucalloc(1+ne, sizeof(int));
-      END = ucalloc(1+ne, sizeof(int));
-      CAP = ucalloc(1+ne, sizeof(double));
-      X = ucalloc(1+ne, sizeof(double));
+      BEG = xcalloc(1+ne, sizeof(int));
+      END = xcalloc(1+ne, sizeof(int));
+      CAP = xcalloc(1+ne, sizeof(double));
+      X = xcalloc(1+ne, sizeof(double));
       /* allocate some auxiliary arrays */
-      ADJ = ucalloc(1+nn, sizeof(int));
-      SUM = ucalloc(1+nn, sizeof(double));
-      CUT = ucalloc(1+nn, sizeof(int));
+      ADJ = xcalloc(1+nn, sizeof(int));
+      SUM = xcalloc(1+nn, sizeof(double));
+      CUT = xcalloc(1+nn, sizeof(int));
       /* currently no min cut is known so far */
       min_cut = DBL_MAX;
       /* main loop starts here */
@@ -694,7 +693,7 @@ static double stoer_wagner(int nn, int ne, int beg[], int end[],
                      supernodes (if not added yet) */
                   if (SUM[J] == 0.0) ADJ[++DEG] = J;
                   /* sum up the capacity of the original edge */
-                  insist(cap[k] > 0.0);
+                  xassert(cap[k] > 0.0);
                   SUM[J] += cap[k];
                }
                /* walk through edges with end[k] = i */
@@ -708,7 +707,7 @@ static double stoer_wagner(int nn, int ne, int beg[], int end[],
                      supernodes (if not added yet) */
                   if (SUM[J] == 0.0) ADJ[++DEG] = J;
                   /* sum up the capacity of the original edge */
-                  insist(cap[k] > 0.0);
+                  xassert(cap[k] > 0.0);
                   SUM[J] += cap[k];
                }
             }
@@ -717,7 +716,7 @@ static double stoer_wagner(int nn, int ne, int beg[], int end[],
                the array SUM for subsequent use */
             for (K = 1; K <= DEG; K++)
             {  NE++;
-               insist(NE <= ne);
+               xassert(NE <= ne);
                J = ADJ[K];
                BEG[NE] = I, END[NE] = J, CAP[NE] = SUM[J];
                SUM[J] = 0.0;
@@ -735,7 +734,7 @@ static double stoer_wagner(int nn, int ne, int beg[], int end[],
             /* determine the min cut in the auxiliary network */
             temp = min_st_cut(NV, NE, BEG, END, CAP, S, T, X, CUT);
             /* check that Ford and Fulkerson are never mistaken :+) */
-            insist(fabs(flow - temp) <= 1e-6 * (1.0 + fabs(flow)));
+            xassert(fabs(flow - temp) <= 1e-6 * (1.0 + fabs(flow)));
             /* determine the min cut in the original network */
             for (i = 1; i <= nn; i++) cut[i] = CUT[NUMB[i]];
             /* if the min cut is close to zero (that obviously means
@@ -747,12 +746,12 @@ static double stoer_wagner(int nn, int ne, int beg[], int end[],
             to the supernodes S and T, into one new supernode; this is
             attained by carrying all nodes from T to S (for the sake of
             convenience T should be the last supernode) */
-         insist(T == NV);
+         xassert(T == NV);
          /* assign new references to nodes from T */
          for (i = HEAD[T]; i != 0; i = NEXT[i]) NUMB[i] = S;
          /* find the last entry in the node list of S */
          i = HEAD[S];
-         insist(i != 0);
+         xassert(i != 0);
          while (NEXT[i] != 0) i = NEXT[i];
          /* and attach to it the node list of T */
          NEXT[i] = HEAD[T];
@@ -760,20 +759,20 @@ static double stoer_wagner(int nn, int ne, int beg[], int end[],
          NV--;
       }
       /* free working arrays */
-      ufree(HEAD);
-      ufree(NEXT);
-      ufree(NUMB);
-      ufree(BEG);
-      ufree(END);
-      ufree(CAP);
-      ufree(X);
-      ufree(ADJ);
-      ufree(SUM);
-      ufree(CUT);
-      ufree(head1);
-      ufree(head2);
-      ufree(next1);
-      ufree(next2);
+      xfree(HEAD);
+      xfree(NEXT);
+      xfree(NUMB);
+      xfree(BEG);
+      xfree(END);
+      xfree(CAP);
+      xfree(X);
+      xfree(ADJ);
+      xfree(SUM);
+      xfree(CUT);
+      xfree(head1);
+      xfree(head2);
+      xfree(next1);
+      xfree(next2);
       /* return to the calling program */
       return min_cut;
 }
@@ -818,24 +817,24 @@ static void gen_subt_row(IOS *ios)
          if (x >= 1e-5) ne++;
       }
       /* create the capacitated network */
-      beg = ucalloc(1+ne, sizeof(int));
-      end = ucalloc(1+ne, sizeof(int));
-      cap = ucalloc(1+ne, sizeof(double));
+      beg = xcalloc(1+ne, sizeof(int));
+      end = xcalloc(1+ne, sizeof(int));
+      cap = xcalloc(1+ne, sizeof(double));
       nz = 0;
       for (k = 1; k <= ncols; k++)
       {  ios_get_col_soln(ios, k, &x, NULL);
          if (x >= 1e-5)
-         {  insist(ios_get_col_mark(ios, k) == EDGE_MARK);
+         {  xassert(ios_get_col_mark(ios, k) == EDGE_MARK);
             edge = ios_get_col_link(ios, k);
             i = edge->i, j = edge->j;
-            insist(1 <= i && i < j && j <= nn);
+            xassert(1 <= i && i < j && j <= nn);
             nz++;
             beg[nz] = i, end[nz] = j, cap[nz] = x;
          }
       }
-      insist(nz == ne);
+      xassert(nz == ne);
       /* find minimal cut in the capacitated network */
-      cut = ucalloc(1+nn, sizeof(int));
+      cut = xcalloc(1+nn, sizeof(int));
       min_cut = stoer_wagner(nn, ne, beg, end, cap, cut);
       /* if the capacity of min cut is less than 2, the corresponding
          subtour elimination constraint is violated */
@@ -854,14 +853,14 @@ static void gen_subt_row(IOS *ios)
          /* determine constraint coefficients for the constraint to be
             generated; each edge that gets into the cut gives non-zero
             constraint coefficient at corresponding column */
-         ind = ucalloc(1+ncols, sizeof(int));
-         val = ucalloc(1+ncols, sizeof(double));
+         ind = xcalloc(1+ncols, sizeof(int));
+         val = xcalloc(1+ncols, sizeof(double));
          len = 0;
          for (k = 1; k <= ncols; k++)
-         {  insist(ios_get_col_mark(ios, k) == EDGE_MARK);
+         {  xassert(ios_get_col_mark(ios, k) == EDGE_MARK);
             edge = ios_get_col_link(ios, k);
             i = edge->i, j = edge->j;
-            insist(1 <= i && i < j && j <= nn);
+            xassert(1 <= i && i < j && j <= nn);
             if (cut[i] && !cut[j] || !cut[i] && cut[j])
             {  len++;
                ind[len] = k;
@@ -874,14 +873,14 @@ static void gen_subt_row(IOS *ios)
          ios_set_row_attr(ios, k, SUBTOUR_MARK, head);
          ios_set_row_bnds(ios, k, IOS_LO, 2.0, 0.0);
          ios_set_mat_row(ios, k, len, ind, val);
-         ufree(ind);
-         ufree(val);
+         xfree(ind);
+         xfree(val);
       }
       /* free working arrays */
-      ufree(cut);
-      ufree(beg);
-      ufree(end);
-      ufree(cap);
+      xfree(cut);
+      xfree(beg);
+      xfree(end);
+      xfree(cap);
       return;
 }
 
@@ -937,7 +936,7 @@ static void select_node(IOS *ios)
 -- the IOS driver at certain points of the optimization process. */
 
 static void appl_proc(IOS *ios, void *info)
-{     insist(info == info);
+{     xassert(info == info);
       switch (ios->event)
       {  case IOS_V_INIT:
             /* create root subproblem */
@@ -975,10 +974,10 @@ static void appl_proc(IOS *ios, void *info)
                   write its (integer) optimal solution to output file
                   in plain text format */
                LPX *lp = ios_extract_lp(ios);
-               insist(lp != NULL);
+               xassert(lp != NULL);
                lpx_set_prob_name(lp, in_file);
-               insist(lpx_warm_up(lp) == LPX_E_OK);
-               insist(lpx_get_status(lp) == LPX_OPT);
+               xassert(lpx_warm_up(lp) == LPX_E_OK);
+               xassert(lpx_get_status(lp) == LPX_OPT);
                lpx_print_sol(lp, out_sol);
                lpx_delete_prob(lp);
             }
@@ -1010,7 +1009,7 @@ static void appl_proc(IOS *ios, void *info)
                   }
                   break;
                default:
-                  insist(ios != ios);
+                  xassert(ios != ios);
             }
             break;
          case IOS_V_DELCOL:
@@ -1025,7 +1024,7 @@ static void appl_proc(IOS *ios, void *info)
                   }
                   break;
                default:
-                  insist(ios != ios);
+                  xassert(ios != ios);
             }
             break;
          default:
@@ -1105,15 +1104,20 @@ int main(int argc, char *argv[])
       /* call the IOS driver */
       ios_driver(appl_proc, NULL);
       /* delete dynamic memory pools */
-      insist(edge_pool->count == 0);
+      xassert(edge_pool->count == 0);
       dmp_delete_pool(edge_pool);
-      insist(subtour_pool->count == 0);
+      xassert(subtour_pool->count == 0);
       dmp_delete_pool(subtour_pool);
       /* delete problem instance */
       tsp_free_data(tsp);
       /* check that no memory blocks have been lost */
-      insist(lib_env_ptr()->mem_total == 0);
-      insist(lib_env_ptr()->mem_count == 0);
+#if 0
+      xassert(lib_env_ptr()->mem_total == 0);
+      xassert(lib_env_ptr()->mem_count == 0);
+#else
+      xassert(ulcmp(lib_link_env()->mem_total, ulset(0, 0)) == 0);
+      xassert(lib_link_env()->mem_count == 0);
+#endif
       /* return to the control program */
       return 0;
 }
