@@ -1,12 +1,12 @@
-/* glpavl.h (binary search trees) */
+/* glpavl.h (binary search tree) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _GLPAVL_H
@@ -28,19 +28,6 @@
 
 #include "glpdmp.h"
 
-#define avl_create_tree       glp_avl_create_tree
-#define avl_strcmp            glp_avl_strcmp
-#define avl_insert_by_key     glp_avl_insert_by_key
-#define avl_find_next_node    glp_avl_find_next_node
-#define avl_find_prev_node    glp_avl_find_prev_node
-#define avl_find_by_key       glp_avl_find_by_key
-#define avl_next_by_key       glp_avl_next_by_key
-#define avl_insert_by_pos     glp_avl_insert_by_pos
-#define avl_find_by_pos       glp_avl_find_by_pos
-#define avl_delete_node       glp_avl_delete_node
-#define avl_rotate_subtree    glp_avl_rotate_subtree
-#define avl_delete_tree       glp_avl_delete_tree
-
 typedef struct AVLTREE AVLTREE;
 typedef struct AVLNODE AVLNODE;
 
@@ -61,7 +48,7 @@ struct AVLTREE
       /* height of the tree */
 };
 
-struct  AVLNODE
+struct AVLNODE
 {     /* node of AVL tree */
       void *key;
       /* pointer to node key (data structure for representing keys is
@@ -92,6 +79,19 @@ struct  AVLNODE
       /* pointer to the root of the right subtree */
 };
 
+#define avl_create_tree       _glp_avl_create_tree
+#define avl_strcmp            _glp_avl_strcmp
+#define avl_insert_by_key     _glp_avl_insert_by_key
+#define avl_find_next_node    _glp_avl_find_next_node
+#define avl_find_prev_node    _glp_avl_find_prev_node
+#define avl_find_by_key       _glp_avl_find_by_key
+#define avl_next_by_key       _glp_avl_next_by_key
+#define avl_insert_by_pos     _glp_avl_insert_by_pos
+#define avl_find_by_pos       _glp_avl_find_by_pos
+#define avl_delete_node       _glp_avl_delete_node
+#define avl_rotate_subtree    _glp_avl_rotate_subtree
+#define avl_delete_tree       _glp_avl_delete_tree
+
 AVLTREE *avl_create_tree(void *info, int (*fcmp)(void *info,
       void *key1, void *key2));
 /* create AVL tree */
