@@ -3,7 +3,7 @@
 /*----------------------------------------------------------------------
 -- This code is part of GNU Linear Programming Kit (GLPK).
 --
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -26,13 +26,6 @@
 #ifndef _GLPDMP_H
 #define _GLPDMP_H
 
-#define dmp_create_pool       glp_dmp_create_pool
-#define dmp_get_atom          glp_dmp_get_atom
-#define dmp_free_atom         glp_dmp_free_atom
-#define dmp_get_atomv         glp_dmp_get_atomv
-#define dmp_free_all          glp_dmp_free_all
-#define dmp_delete_pool       glp_dmp_delete_pool
-
 typedef struct DMP DMP;
 
 struct DMP
@@ -58,6 +51,13 @@ struct DMP
 /* the size of memory blocks, in bytes, allocated for dynamic memory
    pools (all pools use memory blocks of the same size) */
 
+#define dmp_create_pool       _glp_dmp_create_pool
+#define dmp_get_atom          _glp_dmp_get_atom
+#define dmp_free_atom         _glp_dmp_free_atom
+#define dmp_get_atomv         _glp_dmp_get_atomv
+#define dmp_free_all          _glp_dmp_free_all
+#define dmp_delete_pool       _glp_dmp_delete_pool
+
 DMP *dmp_create_pool(int size);
 /* create dynamic memory pool */
 
