@@ -3,7 +3,7 @@
 /*----------------------------------------------------------------------
 -- This code is part of GNU Linear Programming Kit (GLPK).
 --
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -28,61 +28,6 @@
 
 #include "glpstr.h"
 
-#define iet_create_tree       glp_iet_create_tree
-#define iet_install_hook      glp_iet_install_hook
-#define iet_revive_node       glp_iet_revive_node
-#define iet_freeze_node       glp_iet_freeze_node
-#define iet_clone_node        glp_iet_clone_node
-#define iet_set_node_link     glp_iet_set_node_link
-#define iet_delete_node       glp_iet_delete_node
-#define iet_delete_tree       glp_iet_delete_tree
-
-#define iet_get_tree_size     glp_iet_get_tree_size
-#define iet_get_curr_node     glp_iet_get_curr_node
-#define iet_get_next_node     glp_iet_get_next_node
-#define iet_get_prev_node     glp_iet_get_prev_node
-#define iet_get_up_node       glp_iet_get_up_node
-#define iet_get_node_lev      glp_iet_get_node_lev
-#define iet_get_node_cnt      glp_iet_get_node_cnt
-#define iet_get_node_link     glp_iet_get_node_link
-#define iet_pseudo_root       glp_iet_pseudo_root
-
-#define iet_add_rows          glp_iet_add_rows
-#define iet_add_cols          glp_iet_add_cols
-#define iet_check_name        glp_iet_check_name
-#define iet_set_row_name      glp_iet_set_row_name
-#define iet_set_col_name      glp_iet_set_col_name
-#define iet_set_row_link      glp_iet_set_row_link
-#define iet_set_col_link      glp_iet_set_col_link
-#define iet_set_row_bnds      glp_iet_set_row_bnds
-#define iet_set_col_bnds      glp_iet_set_col_bnds
-#define iet_set_obj_coef      glp_iet_set_obj_coef
-#define iet_set_mat_row       glp_iet_set_mat_row
-#define iet_set_mat_col       glp_iet_set_mat_col
-#define iet_set_row_stat      glp_iet_set_row_stat
-#define iet_set_col_stat      glp_iet_set_col_stat
-#define iet_set_row_locl      glp_iet_set_row_locl
-#define iet_set_col_locl      glp_iet_set_col_locl
-#define iet_del_rows          glp_iet_del_rows
-#define iet_del_cols          glp_iet_del_cols
-
-#define iet_get_num_rows      glp_iet_get_num_rows
-#define iet_get_num_cols      glp_iet_get_num_cols
-#define iet_get_num_nz        glp_iet_get_num_nz
-#define iet_get_row_name      glp_iet_get_row_name
-#define iet_get_col_name      glp_iet_get_col_name
-#define iet_get_row_link      glp_iet_get_row_link
-#define iet_get_col_link      glp_iet_get_col_link
-#define iet_get_row_bnds      glp_iet_get_row_bnds
-#define iet_get_col_bnds      glp_iet_get_col_bnds
-#define iet_get_obj_coef      glp_iet_get_obj_coef
-#define iet_get_mat_row       glp_iet_get_mat_row
-#define iet_get_mat_col       glp_iet_get_mat_col
-#define iet_get_row_stat      glp_iet_get_row_stat
-#define iet_get_col_stat      glp_iet_get_col_stat
-#define iet_get_row_locl      glp_iet_get_row_locl
-#define iet_get_col_locl      glp_iet_get_col_locl
-
 typedef struct IET IET;       /* implicit enumeration tree */
 typedef struct IETNPS IETNPS; /* node (sub)problem slot */
 typedef struct IETNPD IETNPD; /* node (sub)problem descriptor */
@@ -477,6 +422,61 @@ struct IETCOL
       /* reserved for higher-level extension */
 };
 
+#define iet_create_tree       _glp_iet_create_tree
+#define iet_install_hook      _glp_iet_install_hook
+#define iet_revive_node       _glp_iet_revive_node
+#define iet_freeze_node       _glp_iet_freeze_node
+#define iet_clone_node        _glp_iet_clone_node
+#define iet_set_node_link     _glp_iet_set_node_link
+#define iet_delete_node       _glp_iet_delete_node
+#define iet_delete_tree       _glp_iet_delete_tree
+
+#define iet_get_tree_size     _glp_iet_get_tree_size
+#define iet_get_curr_node     _glp_iet_get_curr_node
+#define iet_get_next_node     _glp_iet_get_next_node
+#define iet_get_prev_node     _glp_iet_get_prev_node
+#define iet_get_up_node       _glp_iet_get_up_node
+#define iet_get_node_lev      _glp_iet_get_node_lev
+#define iet_get_node_cnt      _glp_iet_get_node_cnt
+#define iet_get_node_link     _glp_iet_get_node_link
+#define iet_pseudo_root       _glp_iet_pseudo_root
+
+#define iet_add_rows          _glp_iet_add_rows
+#define iet_add_cols          _glp_iet_add_cols
+#define iet_check_name        _glp_iet_check_name
+#define iet_set_row_name      _glp_iet_set_row_name
+#define iet_set_col_name      _glp_iet_set_col_name
+#define iet_set_row_link      _glp_iet_set_row_link
+#define iet_set_col_link      _glp_iet_set_col_link
+#define iet_set_row_bnds      _glp_iet_set_row_bnds
+#define iet_set_col_bnds      _glp_iet_set_col_bnds
+#define iet_set_obj_coef      _glp_iet_set_obj_coef
+#define iet_set_mat_row       _glp_iet_set_mat_row
+#define iet_set_mat_col       _glp_iet_set_mat_col
+#define iet_set_row_stat      _glp_iet_set_row_stat
+#define iet_set_col_stat      _glp_iet_set_col_stat
+#define iet_set_row_locl      _glp_iet_set_row_locl
+#define iet_set_col_locl      _glp_iet_set_col_locl
+#define iet_del_rows          _glp_iet_del_rows
+#define iet_del_cols          _glp_iet_del_cols
+
+#define iet_get_num_rows      _glp_iet_get_num_rows
+#define iet_get_num_cols      _glp_iet_get_num_cols
+#define iet_get_num_nz        _glp_iet_get_num_nz
+#define iet_get_row_name      _glp_iet_get_row_name
+#define iet_get_col_name      _glp_iet_get_col_name
+#define iet_get_row_link      _glp_iet_get_row_link
+#define iet_get_col_link      _glp_iet_get_col_link
+#define iet_get_row_bnds      _glp_iet_get_row_bnds
+#define iet_get_col_bnds      _glp_iet_get_col_bnds
+#define iet_get_obj_coef      _glp_iet_get_obj_coef
+#define iet_get_mat_row       _glp_iet_get_mat_row
+#define iet_get_mat_col       _glp_iet_get_mat_col
+#define iet_get_row_stat      _glp_iet_get_row_stat
+#define iet_get_col_stat      _glp_iet_get_col_stat
+#define iet_get_row_locl      _glp_iet_get_row_locl
+#define iet_get_col_locl      _glp_iet_get_col_locl
+
 /**********************************************************************/
 /* * *                  TREE MANAGEMENT ROUTINES                  * * */
 /**********************************************************************/
