@@ -1,12 +1,12 @@
 /* glpios.h (integer optimization suite) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _GLPIOS_H
@@ -28,87 +28,6 @@
 
 #include "glpiet.h"
 
-#define ios_attach_npd        glp_ios_attach_npd
-#define ios_attach_rgd        glp_ios_attach_rgd
-#define ios_attach_cgd        glp_ios_attach_cgd
-#define ios_attach_row        glp_ios_attach_row
-#define ios_attach_col        glp_ios_attach_col
-#define ios_detach_row        glp_ios_detach_row
-#define ios_detach_col        glp_ios_detach_col
-#define ios_hook_routine      glp_ios_hook_routine
-
-#define ios_create_tree       glp_ios_create_tree
-#define ios_revive_node       glp_ios_revive_node
-#define ios_freeze_node       glp_ios_freeze_node
-#define ios_clone_node        glp_ios_clone_node
-#define ios_delete_node       glp_ios_delete_node
-#define ios_delete_tree       glp_ios_delete_tree
-
-#define ios_get_curr_node     glp_ios_get_curr_node
-#define ios_get_next_node     glp_ios_get_next_node
-#define ios_get_prev_node     glp_ios_get_prev_node
-#define ios_get_up_node       glp_ios_get_up_node
-#define ios_get_node_lev      glp_ios_get_node_lev
-#define ios_get_node_cnt      glp_ios_get_node_cnt
-#define ios_pseudo_root       glp_ios_pseudo_root
-
-#define ios_set_obj_dir       glp_ios_set_obj_dir
-#define ios_add_rows          glp_ios_add_rows
-#define ios_add_cols          glp_ios_add_cols
-#define ios_check_name        glp_ios_check_name
-#define ios_set_row_name      glp_ios_set_row_name
-#define ios_set_col_name      glp_ios_set_col_name
-#define ios_set_row_attr      glp_ios_set_row_attr
-#define ios_set_col_attr      glp_ios_set_col_attr
-#define ios_set_col_kind      glp_ios_set_col_kind
-#define ios_set_row_bnds      glp_ios_set_row_bnds
-#define ios_set_col_bnds      glp_ios_set_col_bnds
-#define ios_set_obj_coef      glp_ios_set_obj_coef
-#define ios_set_mat_row       glp_ios_set_mat_row
-#define ios_set_mat_col       glp_ios_set_mat_col
-#define ios_set_row_stat      glp_ios_set_row_stat
-#define ios_set_col_stat      glp_ios_set_col_stat
-#define ios_del_rows          glp_ios_del_rows
-#define ios_del_cols          glp_ios_del_cols
-
-#define ios_get_obj_dir       glp_ios_get_obj_dir
-#define ios_get_num_rows      glp_ios_get_num_rows
-#define ios_get_num_cols      glp_ios_get_num_cols
-#define ios_get_num_nz        glp_ios_get_num_nz
-#define ios_get_row_name      glp_ios_get_row_name
-#define ios_get_col_name      glp_ios_get_col_name
-#define ios_get_row_mark      glp_ios_get_row_mark
-#define ios_get_row_link      glp_ios_get_row_link
-#define ios_get_col_mark      glp_ios_get_col_mark
-#define ios_get_col_link      glp_ios_get_col_link
-#define ios_get_col_kind      glp_ios_get_col_kind
-#define ios_get_row_bnds      glp_ios_get_row_bnds
-#define ios_get_col_bnds      glp_ios_get_col_bnds
-#define ios_get_obj_coef      glp_ios_get_obj_coef
-#define ios_get_mat_row       glp_ios_get_mat_row
-#define ios_get_mat_col       glp_ios_get_mat_col
-
-#define ios_p_status          glp_ios_p_status
-#define ios_d_status          glp_ios_d_status
-#define ios_get_row_soln      glp_ios_get_row_soln
-#define ios_get_col_soln      glp_ios_get_col_soln
-#define ios_get_row_pi        glp_ios_get_row_pi
-#define ios_is_col_frac       glp_ios_is_col_frac
-
-#define ios_extract_lp        glp_ios_extract_lp
-#define ios_put_lp_soln       glp_ios_put_lp_soln
-#define ios_solve_root        glp_ios_solve_root
-#define ios_solve_node        glp_ios_solve_node
-
-#define ios_branch_first      glp_ios_branch_first
-#define ios_branch_last       glp_ios_branch_last
-#define ios_branch_drtom      glp_ios_branch_drtom
-#define ios_branch_on         glp_ios_branch_on
-#define ios_select_fifo       glp_ios_select_fifo
-#define ios_select_lifo       glp_ios_select_lifo
-#define ios_select_node       glp_ios_select_node
-#define ios_driver            glp_ios_driver
-
 typedef struct IOS IOS;       /* integer optimization suite */
 typedef struct IOSNPD IOSNPD; /* node (sub)problem descriptor */
 typedef struct IOSRGD IOSRGD; /* row global descriptor */
@@ -226,10 +145,10 @@ struct IOS
       int it_cnt;
       /* simplex iterations count, that is the total number of simplex
          iterations performed by the LP solver */
-      double tm_beg;
+      ulong_t tm_beg;
       /* starting time of the search, in seconds; the total time of the
          search is the difference between utime() and tm_beg */
-      double tm_lag;
+      ulong_t tm_lag;
       /* the most recent time, in seconds, at which the progress of the
          the search was displayed */
       /*--------------------------------------------------------------*/
@@ -358,6 +277,87 @@ struct IOSCOL
          within given tolerance */
 };
 
+#define ios_attach_npd        _glp_ios_attach_npd
+#define ios_attach_rgd        _glp_ios_attach_rgd
+#define ios_attach_cgd        _glp_ios_attach_cgd
+#define ios_attach_row        _glp_ios_attach_row
+#define ios_attach_col        _glp_ios_attach_col
+#define ios_detach_row        _glp_ios_detach_row
+#define ios_detach_col        _glp_ios_detach_col
+#define ios_hook_routine      _glp_ios_hook_routine
+
+#define ios_create_tree       _glp_ios_create_tree
+#define ios_revive_node       _glp_ios_revive_node
+#define ios_freeze_node       _glp_ios_freeze_node
+#define ios_clone_node        _glp_ios_clone_node
+#define ios_delete_node       _glp_ios_delete_node
+#define ios_delete_tree       _glp_ios_delete_tree
+
+#define ios_get_curr_node     _glp_ios_get_curr_node
+#define ios_get_next_node     _glp_ios_get_next_node
+#define ios_get_prev_node     _glp_ios_get_prev_node
+#define ios_get_up_node       _glp_ios_get_up_node
+#define ios_get_node_lev      _glp_ios_get_node_lev
+#define ios_get_node_cnt      _glp_ios_get_node_cnt
+#define ios_pseudo_root       _glp_ios_pseudo_root
+
+#define ios_set_obj_dir       _glp_ios_set_obj_dir
+#define ios_add_rows          _glp_ios_add_rows
+#define ios_add_cols          _glp_ios_add_cols
+#define ios_check_name        _glp_ios_check_name
+#define ios_set_row_name      _glp_ios_set_row_name
+#define ios_set_col_name      _glp_ios_set_col_name
+#define ios_set_row_attr      _glp_ios_set_row_attr
+#define ios_set_col_attr      _glp_ios_set_col_attr
+#define ios_set_col_kind      _glp_ios_set_col_kind
+#define ios_set_row_bnds      _glp_ios_set_row_bnds
+#define ios_set_col_bnds      _glp_ios_set_col_bnds
+#define ios_set_obj_coef      _glp_ios_set_obj_coef
+#define ios_set_mat_row       _glp_ios_set_mat_row
+#define ios_set_mat_col       _glp_ios_set_mat_col
+#define ios_set_row_stat      _glp_ios_set_row_stat
+#define ios_set_col_stat      _glp_ios_set_col_stat
+#define ios_del_rows          _glp_ios_del_rows
+#define ios_del_cols          _glp_ios_del_cols
+
+#define ios_get_obj_dir       _glp_ios_get_obj_dir
+#define ios_get_num_rows      _glp_ios_get_num_rows
+#define ios_get_num_cols      _glp_ios_get_num_cols
+#define ios_get_num_nz        _glp_ios_get_num_nz
+#define ios_get_row_name      _glp_ios_get_row_name
+#define ios_get_col_name      _glp_ios_get_col_name
+#define ios_get_row_mark      _glp_ios_get_row_mark
+#define ios_get_row_link      _glp_ios_get_row_link
+#define ios_get_col_mark      _glp_ios_get_col_mark
+#define ios_get_col_link      _glp_ios_get_col_link
+#define ios_get_col_kind      _glp_ios_get_col_kind
+#define ios_get_row_bnds      _glp_ios_get_row_bnds
+#define ios_get_col_bnds      _glp_ios_get_col_bnds
+#define ios_get_obj_coef      _glp_ios_get_obj_coef
+#define ios_get_mat_row       _glp_ios_get_mat_row
+#define ios_get_mat_col       _glp_ios_get_mat_col
+
+#define ios_p_status          _glp_ios_p_status
+#define ios_d_status          _glp_ios_d_status
+#define ios_get_row_soln      _glp_ios_get_row_soln
+#define ios_get_col_soln      _glp_ios_get_col_soln
+#define ios_get_row_pi        _glp_ios_get_row_pi
+#define ios_is_col_frac       _glp_ios_is_col_frac
+
+#define ios_extract_lp        _glp_ios_extract_lp
+#define ios_put_lp_soln       _glp_ios_put_lp_soln
+#define ios_solve_root        _glp_ios_solve_root
+#define ios_solve_node        _glp_ios_solve_node
+
+#define ios_branch_first      _glp_ios_branch_first
+#define ios_branch_last       _glp_ios_branch_last
+#define ios_branch_drtom      _glp_ios_branch_drtom
+#define ios_branch_on         _glp_ios_branch_on
+#define ios_select_fifo       _glp_ios_select_fifo
+#define ios_select_lifo       _glp_ios_select_lifo
+#define ios_select_node       _glp_ios_select_node
+#define ios_driver            _glp_ios_driver
+
 /**********************************************************************/
 /* * *               LOW-LEVEL MAINTENANCE ROUTINES               * * */
 /**********************************************************************/
