@@ -1,12 +1,12 @@
-/* glpipm.h (primal-dual interior point method) */
+/* glpipm.h (primal-dual interior-point method) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,21 +19,18 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _GLPIPM_H
 #define _GLPIPM_H
 
-#include "glpmat.h"
+#define ipm_main              _glp_ipm_main
 
-#define ipm1                  glp_ipm1
-#define ipm1_driver           glp_ipm1_driver
-
-extern int ipm1(MAT *A, double b[], double c[], double x[], double y[],
-      double z[]);
-/* primal-dual interior point method for linear programming */
+int ipm_main(int m, int n, int A_ptr[], int A_ind[], double A_val[],
+      double b[], double c[], double x[], double y[], double z[]);
+/* solve LP with primal-dual interior-point method */
 
 #endif
 
