@@ -3,7 +3,7 @@
 /*----------------------------------------------------------------------
 -- This code is part of GNU Linear Programming Kit (GLPK).
 --
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -26,24 +26,6 @@
 #ifndef _GLPLUF_H
 #define _GLPLUF_H
 
-#define luf_create            glp_luf_create
-#define luf_defrag_sva        glp_luf_defrag_sva
-#define luf_enlarge_row       glp_luf_enlarge_row
-#define luf_enlarge_col       glp_luf_enlarge_col
-#define luf_alloc_wa          glp_luf_alloc_wa
-#define luf_free_wa           glp_luf_free_wa
-#define luf_decomp            glp_luf_decomp
-#define luf_f_solve           glp_luf_f_solve
-#define luf_v_solve           glp_luf_v_solve
-#define luf_solve             glp_luf_solve
-#define luf_delete            glp_luf_delete
-
-#define luf_v_sparse          glp_luf_v_sparse
-#define luf_vt_sparse         glp_luf_vt_sparse
-#define luf_f_sparse          glp_luf_f_sparse
-#define luf_ft_sparse         glp_luf_ft_sparse
-#define luf_sparse            glp_luf_sparse
-
 /*----------------------------------------------------------------------
 -- The structure LUF defines LU-factorization of a square matrix A,
 -- which is the following quartet:
@@ -328,6 +310,24 @@ struct LUF_WA
          (in the active submatrix) as the j-th column */
 };
 
+#define luf_create            _glp_luf_create
+#define luf_defrag_sva        _glp_luf_defrag_sva
+#define luf_enlarge_row       _glp_luf_enlarge_row
+#define luf_enlarge_col       _glp_luf_enlarge_col
+#define luf_alloc_wa          _glp_luf_alloc_wa
+#define luf_free_wa           _glp_luf_free_wa
+#define luf_decomp            _glp_luf_decomp
+#define luf_f_solve           _glp_luf_f_solve
+#define luf_v_solve           _glp_luf_v_solve
+#define luf_solve             _glp_luf_solve
+#define luf_delete            _glp_luf_delete
+
+#define luf_v_sparse          _glp_luf_v_sparse
+#define luf_vt_sparse         _glp_luf_vt_sparse
+#define luf_f_sparse          _glp_luf_f_sparse
+#define luf_ft_sparse         _glp_luf_ft_sparse
+#define luf_sparse            _glp_luf_sparse
+
 LUF *luf_create(int n, int sv_size);
 /* create LU-factorization */
 
