@@ -3,7 +3,7 @@
 /*----------------------------------------------------------------------
 -- This code is part of GNU Linear Programming Kit (GLPK).
 --
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -26,17 +26,6 @@
 #ifndef _GLPMAT_H
 #define _GLPMAT_H
 
-#define check_fvs             glp_mat_check_fvs
-#define check_pattern         glp_mat_check_pattern
-#define transpose             glp_mat_transpose
-#define adat_symbolic         glp_mat_adat_symbolic
-#define adat_numeric          glp_mat_adat_numeric
-#define min_degree            glp_mat_min_degree
-#define chol_symbolic         glp_mat_chol_symbolic
-#define chol_numeric          glp_mat_chol_numeric
-#define u_solve               glp_mat_u_solve
-#define ut_solve              glp_mat_ut_solve
-
 /*----------------------------------------------------------------------
 -- FULL-VECTOR STORAGE
 --
@@ -149,6 +138,17 @@
 -- 2. Basic Linear Algebra Subprograms Technical (BLAST) Forum Standard.
 --    University of Tennessee (2001). */
 
+#define check_fvs             _glp_mat_check_fvs
+#define check_pattern         _glp_mat_check_pattern
+#define transpose             _glp_mat_transpose
+#define adat_symbolic         _glp_mat_adat_symbolic
+#define adat_numeric          _glp_mat_adat_numeric
+#define min_degree            _glp_mat_min_degree
+#define chol_symbolic         _glp_mat_chol_symbolic
+#define chol_numeric          _glp_mat_chol_numeric
+#define u_solve               _glp_mat_u_solve
+#define ut_solve              _glp_mat_ut_solve
+
 int check_fvs(int n, int nnz, int ind[], double vec[]);
 /* check sparse vector in full-vector storage format */
 
