@@ -1,19 +1,11 @@
 /* glpqmd.h (quotient minimum degree algorithm) */
 
 /*----------------------------------------------------------------------
--- This file is part of GLPK (GNU Linear Programming Kit).
+-- This code is part of GNU Linear Programming Kit (GLPK).
 --
--- THIS CODE IS THE RESULT OF TRANSLATION OF THE FORTRAN SUBROUTINES
--- GENQMD, QMDRCH, QMDQT, QMDUPD, AND QMDMRG FROM THE BOOK:
---
--- ALAN GEORGE, JOSEPH W-H LIU. COMPUTER SOLUTION OF LARGE SPARSE
--- POSITIVE DEFINITE SYSTEMS. PRENTICE-HALL, 1981.
---
--- THE TRANSLATION HAS BEEN DONE WITH THE PERMISSION OF THE AUTHORS
--- OF THE ORIGINAL FORTRAN SUBROUTINES: ALAN GEORGE AND JOSEPH LIU,
--- UNIVERSITY OF WATERLOO, WATERLOO, ONTARIO, CANADA.
---
--- The translation was made by Andrew Makhorin <mao@mai2.rcnet.ru>.
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+-- Department for Applied Informatics, Moscow Aviation Institute,
+-- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
@@ -27,18 +19,18 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _GLPQMD_H
 #define _GLPQMD_H
 
-#define genqmd                glp_qmd_genqmd
-#define qmdrch                glp_qmd_qmdrch
-#define qmdqt                 glp_qmd_qmdqt
-#define qmdupd                glp_qmd_qmdupd
-#define qmdmrg                glp_qmd_qmdmrg
+#define genqmd                _glp_qmd_genqmd
+#define qmdrch                _glp_qmd_qmdrch
+#define qmdqt                 _glp_qmd_qmdqt
+#define qmdupd                _glp_qmd_qmdupd
+#define qmdmrg                _glp_qmd_qmdmrg
 
 extern void genqmd(int *neqns, int xadj[], int adjncy[], int perm[],
       int invp[], int deg[], int marker[], int rchset[], int nbrhd[],
