@@ -1,12 +1,12 @@
-/* glpstr.h (segmented character strings) */
+/* glpstr.h (segmented character string) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _GLPSTR_H
@@ -28,14 +28,6 @@
 
 #include "glpdmp.h"
 
-#define clear_str             glp_clear_str
-#define compare_str           glp_compare_str
-#define create_str            glp_create_str
-#define create_str_pool       glp_create_str_pool
-#define delete_str            glp_delete_str
-#define get_str               glp_get_str
-#define set_str               glp_set_str
-
 typedef struct STR STR;
 typedef struct SQE SQE;
 
@@ -62,6 +54,14 @@ struct SQE
       /* pointer to the next string element */
 };
 
+#define clear_str             _glp_str_clear_str
+#define compare_str           _glp_str_compare_str
+#define create_str            _glp_str_create_str
+#define create_str_pool       _glp_str_create_str_pool
+#define delete_str            _glp_str_delete_str
+#define get_str               _glp_str_get_str
+#define set_str               _glp_str_set_str
+
 extern STR *clear_str(STR *str);
 /* clear segmented character string */
 
