@@ -3,7 +3,7 @@
 /*----------------------------------------------------------------------
 -- This code is part of GNU Linear Programming Kit (GLPK).
 --
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -26,10 +26,6 @@
 #ifndef _GLPTSP_H
 #define _GLPTSP_H
 
-#define tsp_read_data         glp_tsp_read_data
-#define tsp_free_data         glp_tsp_free_data
-#define tsp_distance          glp_tsp_distance
-
 typedef struct TSP TSP;
 
 struct TSP
@@ -91,6 +87,10 @@ struct TSP
       int *edge_weight; /* int edge_weight[1+dimension*dimension]; */
 };
 
+#define tsp_read_data         _glp_tsp_read_data
+#define tsp_free_data         _glp_tsp_free_data
+#define tsp_distance          _glp_tsp_distance
+
 TSP *tsp_read_data(char *fname);
 /* read TSP instance data */
 
