@@ -3,7 +3,7 @@
 /*----------------------------------------------------------------------
 -- This code is part of GNU Linear Programming Kit (GLPK).
 --
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -23,9 +23,9 @@
 -- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include <string.h>
 #include "glpavl.h"
 #include "glplib.h"
+#define fault xfault1
 
 /*----------------------------------------------------------------------
 -- avl_create_tree - create AVL tree.
@@ -70,7 +70,7 @@
 AVLTREE *avl_create_tree(void *info, int (*fcmp)(void *info,
       void *key1, void *key2))
 {     AVLTREE *tree;
-      tree = umalloc(sizeof(AVLTREE));
+      tree = xmalloc(sizeof(AVLTREE));
       tree->pool = dmp_create_pool(sizeof(AVLNODE));
       tree->info = info;
       tree->fcmp = fcmp;
@@ -109,7 +109,7 @@ AVLTREE *avl_create_tree(void *info, int (*fcmp)(void *info,
 -- p points to. */
 
 int avl_strcmp(void *info, void *key1, void *key2)
-{     insist(info == info);
+{     xassert(info == info);
       return strcmp((char *)key1, (char *)key2);
 }
 
@@ -505,7 +505,7 @@ AVLNODE *avl_find_by_pos(AVLTREE *tree, int pos)
          fault("avl_find_by_pos: pos = %d; invalid position", pos);
       p = tree->root;
       for (;;)
-      {  insist(p != NULL);
+      {  xassert(p != NULL);
          if (pos == p->rank) break;
          if (pos < p->rank)
             p = p->left;
@@ -651,7 +651,7 @@ skip: /* now the specified node [p] has at least one empty subtree;
 
 AVLNODE *avl_rotate_subtree(AVLTREE *tree, AVLNODE *node)
 {     AVLNODE *f, *p, *q, *r, *x, *y;
-      insist(node != NULL);
+      xassert(node != NULL);
       p = node;
       if (p->bal < 0)
       {  /* perform negative (left) rotation */
@@ -743,7 +743,7 @@ AVLNODE *avl_rotate_subtree(AVLTREE *tree, AVLNODE *node)
 
 void avl_delete_tree(AVLTREE *tree)
 {     dmp_delete_pool(tree->pool);
-      ufree(tree);
+      xfree(tree);
       return;
 }
 
