@@ -1,12 +1,12 @@
 /* glpdmp.c */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,13 +19,13 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include <string.h>
 #include "glpdmp.h"
 #include "glplib.h"
+#define fault xfault1
 
 /*----------------------------------------------------------------------
 -- dmp_create_pool - create dynamic memory pool.
@@ -55,7 +55,7 @@ DMP *dmp_create_pool(int size)
 {     DMP *pool;
       if (!(0 <= size && size <= 256))
          fault("dmp_create_pool: size = %d; invalid atom size", size);
-      pool = umalloc(sizeof(DMP));
+      pool = xmalloc(sizeof(DMP));
       pool->size = size;
       pool->avail = NULL;
       pool->link = NULL;
@@ -109,7 +109,7 @@ void *dmp_get_atom(DMP *pool)
          if (blk != NULL)
             pool->stock = *(void **)blk;
          else
-            blk = umalloc(DMP_BLK_SIZE);
+            blk = xmalloc(DMP_BLK_SIZE);
          /* the new block becomes the most recently allocated block */
          *(void **)blk = pool->link;
          pool->link = blk;
@@ -201,7 +201,7 @@ void *dmp_get_atomv(DMP *pool, int size)
          if (blk != NULL)
             pool->stock = *(void **)blk;
          else
-            blk = umalloc(DMP_BLK_SIZE);
+            blk = xmalloc(DMP_BLK_SIZE);
          /* the new block becomes the most recently allocated block */
          *(void **)blk = pool->link;
          pool->link = blk;
@@ -270,14 +270,14 @@ void dmp_delete_pool(DMP *pool)
       while (pool->link != NULL)
       {  blk = pool->link;
          pool->link = *(void **)blk;
-         ufree(blk);
+         xfree(blk);
       }
       while (pool->stock != NULL)
       {  blk = pool->stock;
          pool->stock = *(void **)blk;
-         ufree(blk);
+         xfree(blk);
       }
-      ufree(pool);
+      xfree(pool);
       return;
 }
 
