@@ -3,7 +3,7 @@
 /*----------------------------------------------------------------------
 -- This code is part of GNU Linear Programming Kit (GLPK).
 --
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -23,11 +23,10 @@
 -- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include <math.h>
-#include <stddef.h>
 #include "glpipm.h"
 #include "glplib.h"
 #include "glpmat.h"
+#define print xprint1
 
 /*----------------------------------------------------------------------
 -- ipm_main - solve LP with primal-dual interior-point method.
@@ -243,12 +242,12 @@ static void initialize(struct dsa *dsa, int m, int n, int A_ptr[],
       dsa->x = x;
       dsa->y = y;
       dsa->z = z;
-      dsa->D = ucalloc(1+n, sizeof(double));
+      dsa->D = xcalloc(1+n, sizeof(double));
       /* P := I */
-      dsa->P = ucalloc(1+m+m, sizeof(int));
+      dsa->P = xcalloc(1+m+m, sizeof(int));
       for (i = 1; i <= m; i++) dsa->P[i] = dsa->P[m+i] = i;
       /* S := A*A', symbolically */
-      dsa->S_ptr = ucalloc(1+m+1, sizeof(int));
+      dsa->S_ptr = xcalloc(1+m+1, sizeof(int));
       dsa->S_ind = adat_symbolic(m, n, dsa->P, dsa->A_ptr, dsa->A_ind,
          dsa->S_ptr);
       print("lpx_interior: S has %d non-zeros (upper triangle)",
@@ -257,18 +256,18 @@ static void initialize(struct dsa *dsa, int m, int n, int A_ptr[],
       print("lpx_interior: minimal degree ordering...");
       min_degree(m, dsa->S_ptr, dsa->S_ind, dsa->P);
       /* S = P*A*A'*P', symbolically */
-      ufree(dsa->S_ind);
+      xfree(dsa->S_ind);
       dsa->S_ind = adat_symbolic(m, n, dsa->P, dsa->A_ptr, dsa->A_ind,
          dsa->S_ptr);
-      dsa->S_val = ucalloc(dsa->S_ptr[m+1], sizeof(double));
-      dsa->S_diag = ucalloc(1+m, sizeof(double));
+      dsa->S_val = xcalloc(dsa->S_ptr[m+1], sizeof(double));
+      dsa->S_diag = xcalloc(1+m, sizeof(double));
       /* compute Cholesky factorization S = U'*U, symbolically */
       print("lpx_interior: computing Cholesky factorization...");
-      dsa->U_ptr = ucalloc(1+m+1, sizeof(int));
+      dsa->U_ptr = xcalloc(1+m+1, sizeof(int));
       dsa->U_ind = chol_symbolic(m, dsa->S_ptr, dsa->S_ind, dsa->U_ptr);
       print("lpx_interior: U has %d non-zeros", dsa->U_ptr[m+1]-1 + m);
-      dsa->U_val = ucalloc(dsa->U_ptr[m+1], sizeof(double));
-      dsa->U_diag = ucalloc(1+m, sizeof(double));
+      dsa->U_val = xcalloc(dsa->U_ptr[m+1], sizeof(double));
+      dsa->U_diag = xcalloc(1+m, sizeof(double));
       dsa->iter = 0;
       dsa->obj = 0.0;
       dsa->rpi = 0.0;
@@ -278,22 +277,22 @@ static void initialize(struct dsa *dsa, int m, int n, int A_ptr[],
       dsa->mu = 0.0;
       dsa->rmu = 0.0;
       dsa->rmu0 = 0.0;
-      dsa->phi_min = ucalloc(1+ITER_MAX, sizeof(double));
+      dsa->phi_min = xcalloc(1+ITER_MAX, sizeof(double));
       dsa->best_iter = 0;
-      dsa->best_x = ucalloc(1+n, sizeof(double));
-      dsa->best_y = ucalloc(1+m, sizeof(double));
-      dsa->best_z = ucalloc(1+n, sizeof(double));
+      dsa->best_x = xcalloc(1+n, sizeof(double));
+      dsa->best_y = xcalloc(1+m, sizeof(double));
+      dsa->best_z = xcalloc(1+n, sizeof(double));
       dsa->best_obj = 0.0;
-      dsa->dx_aff = ucalloc(1+n, sizeof(double));
-      dsa->dy_aff = ucalloc(1+m, sizeof(double));
-      dsa->dz_aff = ucalloc(1+n, sizeof(double));
+      dsa->dx_aff = xcalloc(1+n, sizeof(double));
+      dsa->dy_aff = xcalloc(1+m, sizeof(double));
+      dsa->dz_aff = xcalloc(1+n, sizeof(double));
       dsa->alfa_aff_p = 0.0;
       dsa->alfa_aff_d = 0.0;
       dsa->mu_aff = 0.0;
       dsa->sigma = 0.0;
-      dsa->dx_cc = ucalloc(1+n, sizeof(double));
-      dsa->dy_cc = ucalloc(1+m, sizeof(double));
-      dsa->dz_cc = ucalloc(1+n, sizeof(double));
+      dsa->dx_cc = xcalloc(1+n, sizeof(double));
+      dsa->dy_cc = xcalloc(1+m, sizeof(double));
+      dsa->dz_cc = xcalloc(1+n, sizeof(double));
       dsa->dx = dsa->dx_aff;
       dsa->dy = dsa->dy_aff;
       dsa->dz = dsa->dz_aff;
@@ -394,13 +393,13 @@ static int solve_NE(struct dsa *dsa, double y[])
       int i, j, ret = 0;
       double *h, *r, *w;
       /* save vector of right-hand sides h */
-      h = ucalloc(1+m, sizeof(double));
+      h = xcalloc(1+m, sizeof(double));
       for (i = 1; i <= m; i++) h[i] = y[i];
       /* solve normal equation system (A*D*A')*y = h */
       /* since S = P*A*D*A'*P' = U'*U, then A*D*A' = P'*U'*U*P, so we
          have inv(A*D*A') = P'*inv(U)*inv(U')*P */
       /* w := P*h */
-      w = ucalloc(1+m, sizeof(double));
+      w = xcalloc(1+m, sizeof(double));
       for (i = 1; i <= m; i++) w[i] = y[P[i]];
       /* w := inv(U')*w */
       ut_solve(m, dsa->U_ptr, dsa->U_ind, dsa->U_val, dsa->U_diag, w);
@@ -408,17 +407,17 @@ static int solve_NE(struct dsa *dsa, double y[])
       u_solve(m, dsa->U_ptr, dsa->U_ind, dsa->U_val, dsa->U_diag, w);
       /* y := P'*w */
       for (i = 1; i <= m; i++) y[i] = w[P[m+i]];
-      ufree(w);
+      xfree(w);
       /* compute residual vector r = A*D*A'*y - h */
-      r = ucalloc(1+m, sizeof(double));
+      r = xcalloc(1+m, sizeof(double));
       /* w := A'*y */
-      w = ucalloc(1+n, sizeof(double));
+      w = xcalloc(1+n, sizeof(double));
       AT_by_vec(dsa, y, w);
       /* w := D*w */
       for (j = 1; j <= n; j++) w[j] *= dsa->D[j];
       /* r := A*w */
       A_by_vec(dsa, w, r);
-      ufree(w);
+      xfree(w);
       /* r := r - h */
       for (i = 1; i <= m; i++) r[i] -= h[i];
       /* check for numeric stability */
@@ -428,8 +427,8 @@ static int solve_NE(struct dsa *dsa, double y[])
             break;
          }
       }
-      ufree(h);
-      ufree(r);
+      xfree(h);
+      xfree(r);
       return ret;
 }
 
@@ -568,7 +567,7 @@ static void initial_point(struct dsa *dsa)
       for (j = 1; j <= n; j++)
       {  x[j] += dp;
          z[j] += dd;
-         insist(x[j] > 0.0 && z[j] > 0.0);
+         xassert(x[j] > 0.0 && z[j] > 0.0);
       }
       return;
 }
@@ -626,13 +625,13 @@ static void basic_info(struct dsa *dsa)
       for (j = 1; j <= n; j++) temp += c[j] * x[j];
       dsa->obj = temp;
       /* norm1 = ||A*x-b|| */
-      work = ucalloc(1+m, sizeof(double));
+      work = xcalloc(1+m, sizeof(double));
       A_by_vec(dsa, x, work);
       norm1 = 0.0;
       for (i = 1; i <= m; i++)
          norm1 += (work[i] - b[i]) * (work[i] - b[i]);
       norm1 = sqrt(norm1);
-      ufree(work);
+      xfree(work);
       /* bnorm = ||b|| */
       bnorm = 0.0;
       for (i = 1; i <= m; i++) bnorm += b[i] * b[i];
@@ -640,13 +639,13 @@ static void basic_info(struct dsa *dsa)
       /* compute relative primal infeasibility */
       dsa->rpi = norm1 / (1.0 + bnorm);
       /* norm2 = ||A'*y+z-c|| */
-      work = ucalloc(1+n, sizeof(double));
+      work = xcalloc(1+n, sizeof(double));
       AT_by_vec(dsa, y, work);
       norm2 = 0.0;
       for (j = 1; j <= n; j++)
          norm2 += (work[j] + z[j] - c[j]) * (work[j] + z[j] - c[j]);
       norm2 = sqrt(norm2);
-      ufree(work);
+      xfree(work);
       /* cnorm = ||c|| */
       cnorm = 0.0;
       for (j = 1; j <= n; j++) cnorm += c[j] * c[j];
@@ -769,9 +768,9 @@ static int make_step(struct dsa *dsa)
       int i, j, ret = 0;
       double temp, gamma_p, gamma_d, *p, *q, *r;
       /* allocate working arrays */
-      p = ucalloc(1+m, sizeof(double));
-      q = ucalloc(1+n, sizeof(double));
-      r = ucalloc(1+n, sizeof(double));
+      p = xcalloc(1+m, sizeof(double));
+      q = xcalloc(1+n, sizeof(double));
+      r = xcalloc(1+n, sizeof(double));
       /* p = b - A*x */
       A_by_vec(dsa, x, p);
       for (i = 1; i <= m; i++) p[i] = b[i] - p[i];
@@ -843,18 +842,18 @@ static int make_step(struct dsa *dsa)
       /* compute the next point */
       for (j = 1; j <= n; j++)
       {  x[j] += gamma_p * dsa->alfa_max_p * dx[j];
-         insist(x[j] > 0.0);
+         xassert(x[j] > 0.0);
       }
       for (i = 1; i <= m; i++)
          y[i] += gamma_d * dsa->alfa_max_d * dy[i];
       for (j = 1; j <= n; j++)
       {  z[j] += gamma_d * dsa->alfa_max_d * dz[j];
-         insist(z[j] > 0.0);
+         xassert(z[j] > 0.0);
       }
 done: /* free working arrays */
-      ufree(p);
-      ufree(q);
-      ufree(r);
+      xfree(p);
+      xfree(q);
+      xfree(r);
       return ret;
 }
 
@@ -865,26 +864,26 @@ done: /* free working arrays */
 -- all interior-point method routines. */
 
 static void terminate(struct dsa *dsa)
-{     ufree(dsa->D);
-      ufree(dsa->P);
-      ufree(dsa->S_ptr);
-      ufree(dsa->S_ind);
-      ufree(dsa->S_val);
-      ufree(dsa->S_diag);
-      ufree(dsa->U_ptr);
-      ufree(dsa->U_ind);
-      ufree(dsa->U_val);
-      ufree(dsa->U_diag);
-      ufree(dsa->phi_min);
-      ufree(dsa->best_x);
-      ufree(dsa->best_y);
-      ufree(dsa->best_z);
-      ufree(dsa->dx_aff);
-      ufree(dsa->dy_aff);
-      ufree(dsa->dz_aff);
-      ufree(dsa->dx_cc);
-      ufree(dsa->dy_cc);
-      ufree(dsa->dz_cc);
+{     xfree(dsa->D);
+      xfree(dsa->P);
+      xfree(dsa->S_ptr);
+      xfree(dsa->S_ind);
+      xfree(dsa->S_val);
+      xfree(dsa->S_diag);
+      xfree(dsa->U_ptr);
+      xfree(dsa->U_ind);
+      xfree(dsa->U_val);
+      xfree(dsa->U_diag);
+      xfree(dsa->phi_min);
+      xfree(dsa->best_x);
+      xfree(dsa->best_y);
+      xfree(dsa->best_z);
+      xfree(dsa->dx_aff);
+      xfree(dsa->dy_aff);
+      xfree(dsa->dz_aff);
+      xfree(dsa->dx_cc);
+      xfree(dsa->dy_cc);
+      xfree(dsa->dz_cc);
       return;
 }
 
@@ -899,8 +898,8 @@ int ipm_main(int m, int n, int A_ptr[], int A_ind[], double A_val[],
       int i, j, status;
       double temp;
       /* allocate and initialize working area */
-      insist(m > 0);
-      insist(n > 0);
+      xassert(m > 0);
+      xassert(n > 0);
       initialize(dsa, m, n, A_ptr, A_ind, A_val, b, c, x, y, z);
       /* choose initial point using Mehrotra's heuristic */
       print("lpx_interior: guessing initial point...");
@@ -913,7 +912,7 @@ int ipm_main(int m, int n, int A_ptr[], int A_ind[], double A_val[],
          /* save initial value of rmu */
          if (dsa->iter == 0) dsa->rmu0 = dsa->rmu;
          /* accumulate values of min(phi[k]) and save the best point */
-         insist(dsa->iter <= ITER_MAX);
+         xassert(dsa->iter <= ITER_MAX);
          if (dsa->iter == 0 || dsa->phi_min[dsa->iter-1] > dsa->phi)
          {  dsa->phi_min[dsa->iter] = dsa->phi;
             dsa->best_iter = dsa->iter;
