@@ -3,7 +3,7 @@
 /*----------------------------------------------------------------------
 -- This code is part of GNU Linear Programming Kit (GLPK).
 --
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -23,9 +23,6 @@
 -- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include <float.h>
-#include <math.h>
-#include <string.h>
 #include "glplib.h"
 #include "glpmat.h"
 #include "glpqmd.h"
@@ -67,7 +64,7 @@ int check_fvs(int n, int nnz, int ind[], double vec[])
          goto done;
       }
       /* check vector indices */
-      flag = ucalloc(1+n, sizeof(int));
+      flag = xcalloc(1+n, sizeof(int));
       for (i = 1; i <= n; i++) flag[i] = 0;
       for (t = 1; t <= nnz; t++)
       {  i = ind[t];
@@ -90,7 +87,7 @@ int check_fvs(int n, int nnz, int ind[], double vec[])
       }
       /* the vector is ok */
       ret = 0;
-done: if (flag != NULL) ufree(flag);
+done: if (flag != NULL) xfree(flag);
       return ret;
 }
 
@@ -136,7 +133,7 @@ int check_pattern(int m, int n, int A_ptr[], int A_ind[])
          goto done;
       }
       /* check row patterns */
-      flag = ucalloc(1+n, sizeof(int));
+      flag = xcalloc(1+n, sizeof(int));
       for (j = 1; j <= n; j++) flag[j] = 0;
       for (i = 1; i <= m; i++)
       {  /* check pattern of row i */
@@ -162,7 +159,7 @@ int check_pattern(int m, int n, int A_ptr[], int A_ind[])
       }
       /* the pattern is ok */
       ret = 0;
-done: if (flag != NULL) ufree(flag);
+done: if (flag != NULL) xfree(flag);
       return ret;
 }
 
@@ -261,16 +258,16 @@ int *adat_symbolic(int m, int n, int P_per[], int A_ptr[], int A_ind[],
       int *S_ind, *AT_ptr, *AT_ind, *ind, *map, *temp;
       /* build the pattern of A', which is a matrix transposed to A, to
          efficiently access A in column-wise manner */
-      AT_ptr = ucalloc(1+n+1, sizeof(int));
-      AT_ind = ucalloc(A_ptr[m+1], sizeof(int));
+      AT_ptr = xcalloc(1+n+1, sizeof(int));
+      AT_ind = xcalloc(A_ptr[m+1], sizeof(int));
       transpose(m, n, A_ptr, A_ind, NULL, AT_ptr, AT_ind, NULL);
       /* allocate the array S_ind */
       size = A_ptr[m+1] - 1;
       if (size < m) size = m;
-      S_ind = ucalloc(1+size, sizeof(int));
+      S_ind = xcalloc(1+size, sizeof(int));
       /* allocate and initialize working arrays */
-      ind = ucalloc(1+m, sizeof(int));
-      map = ucalloc(1+m, sizeof(int));
+      ind = xcalloc(1+m, sizeof(int));
+      map = xcalloc(1+m, sizeof(int));
       for (jj = 1; jj <= m; jj++) map[jj] = 0;
       /* compute pattern of S; note that symbolically S = B*B', where
          B = P*A, B' is matrix transposed to B */
@@ -296,27 +293,27 @@ int *adat_symbolic(int m, int n, int P_per[], int A_ptr[], int A_ind[],
          if (S_ptr[ii+1] - 1 > size)
          {  temp = S_ind;
             size += size;
-            S_ind = ucalloc(1+size, sizeof(int));
+            S_ind = xcalloc(1+size, sizeof(int));
             memcpy(&S_ind[1], &temp[1], (S_ptr[ii] - 1) * sizeof(int));
-            ufree(temp);
+            xfree(temp);
          }
-         insist(S_ptr[ii+1] - 1 <= size);
+         xassert(S_ptr[ii+1] - 1 <= size);
          /* (ii-th row of S) := (ind) */
          memcpy(&S_ind[S_ptr[ii]], &ind[1], len * sizeof(int));
          /* clear the row pattern map */
          for (t = 1; t <= len; t++) map[ind[t]] = 0;
       }
       /* free working arrays */
-      ufree(AT_ptr);
-      ufree(AT_ind);
-      ufree(ind);
-      ufree(map);
+      xfree(AT_ptr);
+      xfree(AT_ind);
+      xfree(ind);
+      xfree(map);
       /* reallocate the array S_ind to free unused locations */
       temp = S_ind;
       size = S_ptr[m+1] - 1;
-      S_ind = ucalloc(1+size, sizeof(int));
+      S_ind = xcalloc(1+size, sizeof(int));
       memcpy(&S_ind[1], &temp[1], size * sizeof(int));
-      ufree(temp);
+      xfree(temp);
       return S_ind;
 }
 
@@ -363,7 +360,7 @@ void adat_numeric(int m, int n, int P_per[],
       int S_ptr[], int S_ind[], double S_val[], double S_diag[])
 {     int i, j, t, ii, jj, tt, beg, end, beg1, end1, k;
       double sum, *work;
-      work = ucalloc(1+n, sizeof(double));
+      work = xcalloc(1+n, sizeof(double));
       for (j = 1; j <= n; j++) work[j] = 0.0;
       /* compute S = B*D*B', where B = P*A, B' is a matrix transposed
          to B */
@@ -397,7 +394,7 @@ void adat_numeric(int m, int n, int P_per[],
          }
          S_diag[ii] = sum;
       }
-      ufree(work);
+      xfree(work);
       return;
 }
 
@@ -440,20 +437,20 @@ void min_degree(int n, int A_ptr[], int A_ind[], int P_per[])
       ne = A_ptr[n+1] - 1;
       ne += ne;
       /* allocate working arrays */
-      xadj = ucalloc(1+n+1, sizeof(int));
-      adjncy = ucalloc(1+ne, sizeof(int));
-      deg = ucalloc(1+n, sizeof(int));
-      marker = ucalloc(1+n, sizeof(int));
-      rchset = ucalloc(1+n, sizeof(int));
-      nbrhd = ucalloc(1+n, sizeof(int));
-      qsize = ucalloc(1+n, sizeof(int));
-      qlink = ucalloc(1+n, sizeof(int));
+      xadj = xcalloc(1+n+1, sizeof(int));
+      adjncy = xcalloc(1+ne, sizeof(int));
+      deg = xcalloc(1+n, sizeof(int));
+      marker = xcalloc(1+n, sizeof(int));
+      rchset = xcalloc(1+n, sizeof(int));
+      nbrhd = xcalloc(1+n, sizeof(int));
+      qsize = xcalloc(1+n, sizeof(int));
+      qlink = xcalloc(1+n, sizeof(int));
       /* determine row lengths in complete pattern */
       for (i = 1; i <= n; i++) xadj[i] = 0;
       for (i = 1; i <= n; i++)
       {  for (t = A_ptr[i]; t < A_ptr[i+1]; t++)
          {  j = A_ind[t];
-            insist(i < j && j <= n);
+            xassert(i < j && j <= n);
             xadj[i]++, xadj[j]++;
          }
       }
@@ -462,7 +459,7 @@ void min_degree(int n, int A_ptr[], int A_ind[], int P_per[])
       for (i = 1; i <= n; i++)
          len = xadj[i], pos += len, xadj[i] = pos;
       xadj[n+1] = pos;
-      insist(pos - 1 == ne);
+      xassert(pos - 1 == ne);
       /* construct complete pattern */
       for (i = 1; i <= n; i++)
       {  for (t = A_ptr[i]; t < A_ptr[i+1]; t++)
@@ -476,18 +473,18 @@ void min_degree(int n, int A_ptr[], int A_ind[], int P_per[])
       /* make sure that permutation matrix P is correct */
       for (i = 1; i <= n; i++)
       {  j = P_per[i];
-         insist(1 <= j && j <= n);
-         insist(P_per[n+j] == i);
+         xassert(1 <= j && j <= n);
+         xassert(P_per[n+j] == i);
       }
       /* free working arrays */
-      ufree(xadj);
-      ufree(adjncy);
-      ufree(deg);
-      ufree(marker);
-      ufree(rchset);
-      ufree(nbrhd);
-      ufree(qsize);
-      ufree(qlink);
+      xfree(xadj);
+      xfree(adjncy);
+      xfree(deg);
+      xfree(marker);
+      xfree(rchset);
+      xfree(nbrhd);
+      xfree(qsize);
+      xfree(qlink);
       return;
 }
 
@@ -563,13 +560,13 @@ int *chol_symbolic(int n, int A_ptr[], int A_ind[], int U_ptr[])
       size = A_ptr[n+1] - 1;
       if (size < n) size = n;
       size += size;
-      U_ind = ucalloc(1+size, sizeof(int));
+      U_ind = xcalloc(1+size, sizeof(int));
       /* allocate and initialize working arrays */
-      head = ucalloc(1+n, sizeof(int));
+      head = xcalloc(1+n, sizeof(int));
       for (i = 1; i <= n; i++) head[i] = 0;
-      next = ucalloc(1+n, sizeof(int));
-      ind = ucalloc(1+n, sizeof(int));
-      map = ucalloc(1+n, sizeof(int));
+      next = xcalloc(1+n, sizeof(int));
+      ind = xcalloc(1+n, sizeof(int));
+      map = xcalloc(1+n, sizeof(int));
       for (j = 1; j <= n; j++) map[j] = 0;
       /* compute the pattern of matrix U */
       U_ptr[1] = 1;
@@ -582,7 +579,7 @@ int *chol_symbolic(int n, int A_ptr[], int A_ind[], int U_ptr[])
          memcpy(&ind[1], &A_ind[A_ptr[k]], len * sizeof(int));
          for (t = 1; t <= len; t++)
          {  j = ind[t];
-            insist(k < j && j <= n);
+            xassert(k < j && j <= n);
             map[j] = 1;
          }
          /* walk through rows of U whose leftmost non-diagonal non-zero
@@ -602,11 +599,11 @@ int *chol_symbolic(int n, int A_ptr[], int A_ind[], int U_ptr[])
          if (U_ptr[k+1] - 1 > size)
          {  temp = U_ind;
             size += size;
-            U_ind = ucalloc(1+size, sizeof(int));
+            U_ind = xcalloc(1+size, sizeof(int));
             memcpy(&U_ind[1], &temp[1], (U_ptr[k] - 1) * sizeof(int));
-            ufree(temp);
+            xfree(temp);
          }
-         insist(U_ptr[k+1] - 1 <= size);
+         xassert(U_ptr[k+1] - 1 <= size);
          /* (k-th row of U) := (ind) */
          memcpy(&U_ind[U_ptr[k]], &ind[1], len * sizeof(int));
          /* determine column index of leftmost non-diagonal non-zero in
@@ -620,16 +617,16 @@ int *chol_symbolic(int n, int A_ptr[], int A_ind[], int U_ptr[])
          if (min_j <= n) next[k] = head[min_j], head[min_j] = k;
       }
       /* free working arrays */
-      ufree(head);
-      ufree(next);
-      ufree(ind);
-      ufree(map);
+      xfree(head);
+      xfree(next);
+      xfree(ind);
+      xfree(map);
       /* reallocate the array U_ind to free unused locations */
       temp = U_ind;
       size = U_ptr[n+1] - 1;
-      U_ind = ucalloc(1+size, sizeof(int));
+      U_ind = xcalloc(1+size, sizeof(int));
       memcpy(&U_ind[1], &temp[1], size * sizeof(int));
-      ufree(temp);
+      xfree(temp);
       return U_ind;
 }
 
@@ -717,7 +714,7 @@ int chol_numeric(int n,
       int U_ptr[], int U_ind[], double U_val[], double U_diag[])
 {     int i, j, k, t, t1, beg, end, beg1, end1, count = 0;
       double ukk, uki, *work;
-      work = ucalloc(1+n, sizeof(double));
+      work = xcalloc(1+n, sizeof(double));
       for (j = 1; j <= n; j++) work[j] = 0.0;
       /* U := (upper triangle of A) */
       /* note that the upper traingle of A is a subset of U */
@@ -745,7 +742,7 @@ int chol_numeric(int n,
          /* transform other rows of U */
          for (t = beg; t < end; t++)
          {  i = U_ind[t];
-            insist(i > k);
+            xassert(i > k);
             /* (i-th row) := (i-th row) - u[k,i] * (k-th row) */
             uki = work[i];
             beg1 = U_ptr[i], end1 = U_ptr[i+1];
@@ -757,7 +754,7 @@ int chol_numeric(int n,
          for (t = beg; t < end; t++)
             work[U_ind[t]] = 0.0;
       }
-      ufree(work);
+      xfree(work);
       return count;
 }
 
@@ -797,7 +794,7 @@ void u_solve(int n, int U_ptr[], int U_ind[], double U_val[],
          beg = U_ptr[i], end = U_ptr[i+1];
          for (t = beg; t < end; t++)
             temp -= U_val[t] * x[U_ind[t]];
-         insist(U_diag[i] != 0.0);
+         xassert(U_diag[i] != 0.0);
          x[i] = temp / U_diag[i];
       }
       return;
@@ -835,7 +832,7 @@ void ut_solve(int n, int U_ptr[], int U_ind[], double U_val[],
 {     int i, t, beg, end;
       double temp;
       for (i = 1; i <= n; i++)
-      {  insist(U_diag[i] != 0.0);
+      {  xassert(U_diag[i] != 0.0);
          temp = (x[i] /= U_diag[i]);
          if (temp == 0.0) continue;
          beg = U_ptr[i], end = U_ptr[i+1];
